@@ -4,10 +4,10 @@
 
 // flags showing last transmit mode, for auto-transmit function
 // using the same defines as for the hfapp messages 
-int lasttx = 0, lastrx = 0;
 int fbbtest = 0;
 int way = TX, beacon_file_prepared = 0, mailbox_prepared = 0;
 extern GtkWidget *textmain;
+extern guint squelch;
 
 /* --- File menu ----------------------------------------------------- */ 
 
@@ -19,27 +19,49 @@ void on_tx_file_activate(GtkMenuItem *menuitem, gpointer user_data)
 void on_beacon_file_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	if (beacon_on == 0) {
-	    beacon_on = 1;
-	    if (beacon_file_prepared == 0) {
-	        beacon_file_prepare();
-	        beacon_file_prepared = 1;
-	        display_status("beacon from file prepared ...");
-		return;
+	    if ((beacon_file_prepared == 0) && (fixbeacon == 0)) {
+		/* 
+		 * if no file and no fixtext prepared for beacon:
+		 * prepare a file.
+		 * If user wants to send fixtext as beacon,
+		 * he / she clicks on fixtext button.
+		 */	    
+		if ( beacon_file_prepare())  { // if file o.k.
+		    display_status
+			("Beacon file prepared, beacon running.");
+	    	    beacon_file_prepared = 1;
+		    beacon_on = 1;
+		    beacon_send();
+		    // must be started one time, from then on by loop in msg.c 
+		    return;
+		} else {
+		    beacon_file_prepared = 0;
+	    	    display_status("Beacon file could not be prepared ...");
+		    beacon_on = 0;
+		    return;
+		}
 	    }
 	    else {
-		beacon_send();
+		/* 
+		 * if file OR fixtext prepared for beacon:
+		 * just switch on the beacon modus.
+		 */
+		beacon_on = 1;
+		display_status
+		 ("Beacon already prepared, I switch it on.");
+	    	 beacon_send(); 
+		 // must be started one time, from then on by loop in msg.c 
 		return;
 	    }
 	}
 	if (beacon_on == 1) {
 	    beacon_on = 0;
 	    beacon_stop();	
-	    display_status("beacon off");
+	    display_status("Beacon mode off.");
 	    return;
 	}
 }
 
-
 /* --- Spektrum ----------------------------------------------------- */ 
 void on_frequency_spectrum_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
@@ -50,9 +72,6 @@ void on_frequency_spectrum_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.data.u = htonl(SPECTRUM_NUMSAMPLES);
 	msg_send(&msg);
 	scope_on = 1;
-	// test:
-	set_fsk_freq(params.fsk.freq[0], params.fsk.freq[1]);
-	set_freq_shift(params.fsk.freq[1] - params.fsk.freq[0]);
 	gtk_widget_show(wspec);
 	return;
 	
@@ -74,7 +93,6 @@ gboolean on_spec_motion_event(GtkWidget *widget, GdkEventMotion *event, gpointer
 	return FALSE;
 }
 
-
 gboolean on_spec_button_press_event(GtkWidget *widget, GdkEventButton *event, gpointer user_data)
 {
 	unsigned int freq;
@@ -82,52 +100,90 @@ gboolean on_spec_button_press_event(GtkWidget *widget, GdkEventButton *event, gp
 	static unsigned int freq1 = 0, freq2 = 0;
 	static int clickcount = 0;
 	int usershift = 0;
+	guint squelchvalue;
 
 	shift = get_freq_shift();	
 	freq = ((SRATE/2) * event->x + SPECTRUM_WIDTH/2) / SPECTRUM_WIDTH;
-
+	squelchvalue = event->y;
+	
 	if (shift) {
 	    switch (event->button) {
 		case 1:
 		    set_fsk_freq(freq, freq+shift);
 		    break;
-
 		case 2:
 		    set_fsk_freq(freq-shift/2, freq+shift/2);
 		    break;
-
+		/*
 		case 3:
 		    set_fsk_freq(freq-shift, freq);
 		    break;
+		*/
+/* i borrow the right mouse button for squelch!
+ * since now squelch-set works o.k. but 2nd button not working
+ * any more for middlefreq...
+ * but it is midnight almost. I stop for today. 19.jan 2005
+ */
+		case 3:
+		    squelch = squelchvalue;
+		    display_status("set squelch to %d", squelch);
+		    break;
 	    }
 	return FALSE;
 	}
 	if (shift == 0) {
 	    display_status 
     		("user-defined shift. Click 2 times to set mark and space.");
-	    clickcount++;
-		if (clickcount == 1) {
-		    freq1 = freq;
-		    freq = 0;
-		    display_status ("First frequency: %d", freq1);
-		    set_fsk_freq(freq1, freq1+1);
-		}
-		if (clickcount == 2) {
-		    freq2 = freq;
-		    display_status ("Second frequency: %d.");
-		    clickcount = 0;
-		    usershift = max(freq1, freq2) - min(freq1, freq2);
-		    display_status 
-			(" Will set mark & space. Shift is %d",  usershift);
-		    set_fsk_freq(min(freq1, freq2), max(freq1, freq2));
-		    freq1 = freq2 = 0;
-		    usershift = 0;
+	    switch (event->button) {
+		case 1:
+		case 2:
+		    clickcount++;
+		    if (clickcount == 1) {
+			freq1 = freq;
+			freq = 0;
+			//display_status ("First frequency: %d", freq1);
+			set_fsk_freq(freq1, freq1+1);
+			break;
+		    }
+		    if (clickcount == 2) {
+			freq2 = freq;
+			//display_status ("Second frequency: %d.");
+			clickcount = 0;
+			usershift = max(freq1, freq2) - min(freq1, freq2);
+			//display_status 
+			//(" Will set mark & space. Shift is %d",  usershift);
+			set_fsk_freq(min(freq1, freq2), max(freq1, freq2));
+			freq1 = freq2 = 0;
+			usershift = 0;
+			break;
+	    	    }
+		    break;
+		case 3:
+		    squelch = squelchvalue;
+		    display_status("set squelch to %d", squelch);
+		    break;
 	    }
 	}
 //	printf("on_scope_button_press_event: x %g y %g  button 0x%04x\n", event->x, event->y, event->button);
 	return FALSE;
 }
 
+/* works n o t */
+void on_squelchruler_click_event
+    (GtkWidget *widget, GdkEventButton *event, gpointer user_data)
+{
+	guint i = event->y;
+	
+	switch (event->button) {
+	    case 1:
+	    case 2:
+	    case 3:
+		display_status 
+    		    ("user-defined squelch %d", squelch);
+	    	squelch = i;
+	}
+}
+
 gboolean on_wspec_delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data)
 {
 	gtk_widget_hide(widget);
@@ -169,8 +225,8 @@ void on_become_irs_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_MODE_IRS);
 	msg_send(&msg);
 	display_status("SLAVE");
-	lastrx = HFAPP_MSG_MODE_IRS;
-	userrx();
+	lastrxcmd = HFAPP_MSG_MODE_IRS;
+	way = RX;
 }
 
 void on_become_iss_activate(GtkMenuItem *menuitem, gpointer user_data)
@@ -182,7 +238,7 @@ void on_become_iss_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_MODE_ISS);
 	msg_send(&msg);
 	display_status("MASTER");
-	lasttx = HFAPP_MSG_MODE_ISS;
+	lasttxcmd = HFAPP_MSG_MODE_ISS;
 	usertx();
 }
 
@@ -194,12 +250,10 @@ void on_qrt_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_MODE_QRT);
 	msg_send(&msg);
 	display_status("QRT");
-	lasttx = HFAPP_MSG_MODE_QRT;
-	autorx_on = 1;
-	qrt_pending = 0;
+	lasttxcmd = HFAPP_MSG_MODE_QRT;
+	beacon_restore();
 }
 
-
 void on_speedup_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	struct hfapp_msg msg;
@@ -256,13 +310,19 @@ void on_mailbox_activate(GtkMenuItem *menuitem, gpointer user_data)
 		return;
 	}
 	if (mailbox_on == 1) {
-	
-		mailbox_close();
+		mailbox_loggedout();
 		display_status
 		    ("Mailbox mode off. You can activate it again by <Alt> M.");
+		// in case of mailbox-advertising in beacon...
+		if (beacon_on) {
+		    beacon_on = 0;
+		    display_status
+		    ("I also switched the beacon off."
+		    "(For sure, as it could have announced the mailbox.)"
+		    "You can activate the beacon again by <Alt> B.");
+		}
 		mailbox_on = 0;
 		autorx_on = 1;
-//		gtk_text_set_editable (GTK_TEXT (textmain), FALSE);
 		return;
 	}
 }
@@ -276,9 +336,13 @@ void on_standby_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_STANDBY);
 	msg_send(&msg);
 	display_status("STANDBY FOR PACTOR - AMTOR - GTOR");
-	lastrx = HFAPP_MSG_START_STANDBY;
+	lastrxcmd = HFAPP_MSG_START_STANDBY;
+	/* to prevent for autotx "remembering" last rx msg from hfkernel ,
+	   which may be irrelevant */
+	lastrxmsg = 0;
 	qrt_pending = 0;
-	userrx();
+	way = RX;
+	beacon_restore();
 }
 
 void on_standby_pactor_activate(GtkMenuItem *menuitem, gpointer user_data)
@@ -290,9 +354,13 @@ void on_standby_pactor_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_PACTOR_STANDBY);
 	msg_send(&msg);
 	display_status("STANDBY FOR PACTOR ");
-	lastrx = HFAPP_MSG_START_PACTOR_STANDBY;
+	lastrxcmd = HFAPP_MSG_START_PACTOR_STANDBY;
+	/* to prevent for autotx "remembering" last rx msg from hfkernel ,
+	   which may be irrelevant */
+	lastrxmsg = 0;
 	qrt_pending = 0;
-	userrx();
+	way = RX;
+	beacon_restore();
 }
 
 void on_pactor_arq_activate(GtkMenuItem *menuitem, gpointer user_data)
@@ -304,9 +372,9 @@ void on_pactor_arq_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_PACTOR_ARQ);
 	msg_send(&msg);
 	display_status("PACTOR-ARQ");
-	lasttx = HFAPP_MSG_START_PACTOR_ARQ;
+	lasttxcmd = HFAPP_MSG_START_PACTOR_ARQ;
 	qrt_pending = 0;	
-	usertx();
+	beacon_suspend();
 }
 
 void on_pactor_fec_activate(GtkMenuItem *menuitem, gpointer user_data)
@@ -318,7 +386,7 @@ void on_pactor_fec_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_PACTOR_FEQ);
 	msg_send(&msg);
 	display_status("PACTOR-FEC");
-	lasttx = HFAPP_MSG_START_PACTOR_FEQ;
+	lasttxcmd = HFAPP_MSG_START_PACTOR_FEQ;
 	qrt_pending = 0;
 	usertx();
 }
@@ -333,9 +401,9 @@ void on_gtor_arq1_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_GTOR_ARQ);
 	msg_send(&msg);
 	display_status("GTOR-ARQ");
-	lasttx = HFAPP_MSG_START_GTOR_ARQ;
+	lasttxcmd = HFAPP_MSG_START_GTOR_ARQ;
 	qrt_pending = 0;
-	usertx();
+	beacon_suspend();
 }
 
 
@@ -348,12 +416,11 @@ void on_amtor_arq_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_AMTOR_ARQ);
 	msg_send(&msg);
 	display_status("AMTOR-ARQ");
-	lasttx = HFAPP_MSG_START_AMTOR_ARQ;
+	lasttxcmd = HFAPP_MSG_START_AMTOR_ARQ;
 	qrt_pending = 0;
-	usertx();
+	beacon_suspend();
 }
 
-
 void on_amtor_collective_fec_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	struct hfapp_msg msg;
@@ -363,7 +430,7 @@ void on_amtor_collective_fec_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_AMTOR_COLFEQ);
 	msg_send(&msg);
 	display_status("AMTOR-COLFEC");
-	lasttx = HFAPP_MSG_START_AMTOR_COLFEQ;
+	lasttxcmd = HFAPP_MSG_START_AMTOR_COLFEQ;
 	qrt_pending = 0;
 	usertx();
 }
@@ -377,7 +444,7 @@ void on_amtor_selective_fec_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_AMTOR_SELFEQ);
 	msg_send(&msg);
 	display_status("AMTOR-SELFEC");
-	lasttx = HFAPP_MSG_START_AMTOR_SELFEQ;
+	lasttxcmd = HFAPP_MSG_START_AMTOR_SELFEQ;
 	qrt_pending = 0;
 	usertx();
 }
@@ -391,12 +458,11 @@ void on_rtty_receive_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_RTTY_RX);
 	msg_send(&msg);
 	display_status("RTTY-RX");
-	lastrx = HFAPP_MSG_START_RTTY_RX;
+	lastrxcmd = HFAPP_MSG_START_RTTY_RX;
 	qrt_pending = 0;
-	userrx();
+	way = RX;
 }
 
-
 void on_rtty_transmit_activate(GtkMenuItem *menuitem, gpointer user_data)
 {
 	struct hfapp_msg msg;
@@ -406,7 +472,35 @@ void on_rtty_transmit_activate(GtkMenuItem *menuitem, gpointer user_data)
 	msg.hdr.type = htonl(HFAPP_MSG_START_RTTY_TX);
 	msg_send(&msg);
 	display_status("RTTY-TX");
-	lasttx = HFAPP_MSG_START_RTTY_TX;
+	lasttxcmd = HFAPP_MSG_START_RTTY_TX;
+	qrt_pending = 0;
+	usertx();
+}
+
+void on_mt63_rx_activate(GtkMenuItem *menuitem, gpointer user_data)
+{
+	struct hfapp_msg msg;
+
+	msg.hdr.err = htonl(ERR_NOERR);
+	msg.hdr.len = htonl(0);
+	msg.hdr.type = htonl(HFAPP_MSG_START_MT63_RX);
+	msg_send(&msg);
+	display_status("MT63-RX");
+	lastrxcmd = HFAPP_MSG_START_MT63_RX;
+	qrt_pending = 0;
+	way = RX;
+}
+
+void on_mt63_tx_activate(GtkMenuItem *menuitem, gpointer user_data)
+{
+	struct hfapp_msg msg;
+
+	msg.hdr.err = htonl(ERR_NOERR);
+	msg.hdr.len = htonl(0);
+	msg.hdr.type = htonl(HFAPP_MSG_START_MT63_TX);
+	msg_send(&msg);
+	display_status("MT63-TX");
+	lasttxcmd = HFAPP_MSG_START_MT63_TX;
 	qrt_pending = 0;
 	usertx();
 }
@@ -612,26 +706,29 @@ gboolean on_rx_keyrelease_event(GtkWidget *widget, GdkEventKey *event, gpointer
 /* for transmit by keyboard */
 gboolean on_tx_keypress_event(GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
-
-//	char c = event->keyval;
+//	int c = event->keyval;
 //	printf("on_text_keypress_event: 0x%x %c  state %u\n",
 //	event->keyval, (c >= ' ' && c <= 0x7f) ? c : '.', event->state);
-
+//	display_status("tx keypress");
+/*
+	display_status("tx keypress: hex 0x%x is char %c",
+	    c, (c >= 32 && c < 128) ? c : '.');
+*/		
 	if (event->state & ~(GDK_SHIFT_MASK | GDK_LOCK_MASK))
 		return FALSE;
 	
 	if (event->keyval == GDK_BackSpace) {
-		if (!autotx_on) autotx();
+		if( way == RX) autotx();
 		edit_backspace();
 		return TRUE;
 	}
 	if (event->keyval == GDK_Return) {
-		if (!autotx_on) autotx();
+		if( way == RX) autotx();
 		edit_newline();
 		return TRUE;
 	}
 	if (event->keyval >= 32 && event->keyval < 128) {
-		if (!autotx_on) autotx();
+		if( way == RX) autotx();
 		edit_addchar(event->keyval);
 		return TRUE;
 	}
