@@ -405,7 +405,7 @@ create_Wfixtext (void)
   gtk_container_add (GTK_CONTAINER (scrolledwindow10), text10);
   gtk_text_set_editable (GTK_TEXT (text10), TRUE);
 
-  label10 = gtk_label_new (_("10 wx"));
+  label10 = gtk_label_new (_("10 mailbox"));
   gtk_widget_set_name (label10, "label10");
   gtk_widget_ref (label10);
   gtk_object_set_data_full (GTK_OBJECT (Wfixtext), "label10", label10,
