@@ -304,7 +304,7 @@ create_whilfe (void)
   gtk_container_add (GTK_CONTAINER (scrw_help_1), text_help_1);
   gtk_tooltips_set_tip (tooltips, text_help_1, _("Left Side English \nRight Side German"), NULL);
   gtk_text_set_editable (GTK_TEXT (text_help_1), FALSE);
-  textinsert("/usr/share/hf/HF-HOWTO.txt  ", GTK_TEXT(text_help_1));
+  //textinsert("/usr/share/hf/HF-HOWTO.txt  ", GTK_TEXT(text_help_1));
 
   label_help_1 = gtk_label_new (_(""));
   gtk_widget_set_name (label_help_1, "label_help_1");
