@@ -604,7 +604,7 @@ create_wqsoeditor (void)
   combo4_items = g_list_append (combo4_items, (gpointer) _("Pactor"));
   combo4_items = g_list_append (combo4_items, (gpointer) _("GTOR"));
   combo4_items = g_list_append (combo4_items, (gpointer) _("FSK"));
-  combo4_items = g_list_append (combo4_items, (gpointer) _("/*PSK31*/"));
+  combo4_items = g_list_append (combo4_items, (gpointer) _("MT63"));
   combo4_items = g_list_append (combo4_items, (gpointer) _("/*300 bd Packet Radio*/"));
   gtk_combo_set_popdown_strings (GTK_COMBO (combo4), combo4_items);
   g_list_free (combo4_items);
