@@ -44,9 +44,11 @@
 
 /* --------------------------------------------------------------------- */
 
+#define MAILBOX_IN_DATA_LEN 512
 int mailbox_on = 0, mailbox_connected = 0, mailbox_fd = -1;
 int mailbox_pactor_login = 0, mailbox_output_waiting = 0;
 int port, txwaitbytes  = 0;
+int mailbox_input_waiting = 0;
 char *ipaddress;
 // these two are options to hfterm
 // note in f6fbb doc examples the port is 6300, hex 189C
@@ -87,69 +89,96 @@ void mailbox_input(unsigned char *data, int datalen) {
  * for check. 
  *
  * If last character of input is \n (newline) or \r (carriage return)
- * mailbox_check() is invoked to start dialog with the mailbox program 
+ * mailbox_check_io() is invoked to start dialog with the mailbox program 
  * via the telnet port.
  *
  */
 	int i = 0;
+
 	char c = 0, call[16];
-	
+	unsigned char mailbox_in_data[MAILBOX_IN_DATA_LEN];
+
 	if (!mailbox_on) {
 	    display_status (   
 	     "mailbox_rx_2_inbuf: mailbox mode off. ");
 	    return;
 	}
-	
-	if (mailbox_output_waiting) {
+/*
+ *  provide that we are not called if data are still being processed
+ *  on their way to mailbox program or within it ...
+ */	
+	if (mailbox_input_waiting) {
 	    display_status (   
-	     "mailbox_input: mailbox output is still waiting"
-	     "so i do'nt accept new mailbox input for now!");
-	    mailbox_clear_inbuf();
+	     "mailbox_input: last input still in process \n"
+	     "-> I don't accept new input for now.");
 	    return;
 	}
-
 /*
- *  for checking, if our call, toupperize input 
+ *  provide that we are not called if data are still being processed
+ *  on their way from mailbox program to transmit, which is artifically 
+ *  delayed so that remote user can switch from tx to rx ...
+ */	
+	if (mailbox_output_waiting) {
+	    display_status (   
+	     "mailbox_input: output still waiting for transmit \n"
+	     "-> I don't accept new input for now.");
+	    return;
+	}
+/*
+ *  first copy data into our own buffer, 
+ *  so that the original data is not 'toupperized' in case we use the 
+ *  call detection machine. 
+ */	
+	if (datalen >= MAILBOX_IN_DATA_LEN) {
+	    display_status (   
+	     "mailbox_input: buffer too short. Will cut end of data.");
+	}
+	memset(mailbox_in_data, 0, sizeof (mailbox_in_data));
+	for (i = 0;  i < datalen && i < MAILBOX_IN_DATA_LEN; i++) {
+	    mailbox_in_data[i] = (char)data[i];
+	}
+/*
+ *  to make the check easier, if our call is called, toupperize input 
  */	
 	if (! mailbox_connected) {
-	
-	    for (i = 0; i < datalen && i < BUF_SIZE - buf_hf2box_avail; i++) {
-		if (islower(data[i])) {
-		    c = toupper(data[i]);
-		    data[i] = c;
-		}
-	    }
 	    /*
 	    display_status (
 		//"Mailbox not yet connected.\n"
-		"Capitalized input to simplify check for my call.\n"       		
-		"%s", data);
-	*/
+		"Capitalizing input to simplify check for my call...\n"       		
+		"%s", mailbox_in_data);
+	    */
+	    for (i = 0; i < datalen && i < BUF_SIZE - buf_hf2box_avail; i++) {
+		if (islower(mailbox_in_data[i])) {
+		    c = toupper(mailbox_in_data[i]);
+		    mailbox_in_data[i] = c;
+		}
+	    }
 	} 
 	/*
 	else {
 	    display_status 
 	        ( "Mailbox is connected. I received data:\n"       		
-		"%s", data);
+		"%s", mailbox_in_data);
 	}
 	*/
 /*
- * write received data to buffer:
+ * write received mailbox_in_data to port-buffer:
  */	
-	sprintf(buf_hf2box + buf_hf2box_avail, "%s", data);	
+	sprintf(buf_hf2box + buf_hf2box_avail, "%s", mailbox_in_data);	
 	in_oldavail = buf_hf2box_avail; 
 	buf_hf2box_avail+= datalen;
 /*
 	display_status 
-	    ( "New data now in mailbox input buffer:\n"       		
+	    ( "New mailbox_in_data now in mailbox input buffer:\n"       		
 	    "%s", buf_hf2box + in_oldavail);
 	display_status (   
 	     "All data in mailbox input buffer: %s ", buf_hf2box);       		
 */
+
 /*
  * special case: new pactor connect:
  */	
-	if (lastrx == HFAPP_MSG_STATE_PACTOR_ARQ_SLAVECONNECT &&
+	if (lastrxmsg == HFAPP_MSG_STATE_PACTOR_ARQ_SLAVECONNECT &&
 	    mailbox_connected == 0) {
 /*
 	    display_status ( 
@@ -166,44 +195,59 @@ void mailbox_input(unsigned char *data, int datalen) {
  */
 	    sprintf(call, "%s", buf_hf2box + in_oldavail + 1);
 	    mailbox_clear_inbuf();	    
-	    sprintf(buf_hf2box, "%s", call);
-	    buf_hf2box_avail = strlen(call);
-	    memset (buf_hf2box+buf_hf2box_avail -1, 0, 
-		BUF_SIZE - buf_hf2box_avail); 
-//	    display_status (   
-//		 "mailbox_input: cleaned call: %s", call);      		
+	    sprintf(buf_hf2box, "%s\n", call); 	 //	"%s", call);
+	    buf_hf2box_avail = strlen(call) + 1; //	;
 	    display_status (   
-		 "mailbox_input: result of call cleaning action: %s",
-		  buf_hf2box);      		
+		 "mailbox_input: pactor remote call: " 
+		 "%s", buf_hf2box);      		
 	    in_oldavail = 0;
-	    mailbox_clear_outbuf();
-	    mailbox_check();
-	    return;
+	    goto invoke_mailbox_check_io;	
 	}
 
 /*
- * now finally we call mailbox_check, which will process the input buffer
+ * special case: new amtor connect:
+ */	
+	else if (lastrxmsg == HFAPP_MSG_STATE_AMTOR_ARQ_SLAVECONNECT &&
+	    mailbox_connected == 0) {
+	    display_status ( 
+	        "mailbox_input: Amtor ARQ slave connect! "
+		"Will check mailbox.");       		
+	    goto invoke_mailbox_check_io;	
+	}
+
+/*
+ * case of FEC-signal, last sign is cr or nl:
  */	
 	if (buf_hf2box[buf_hf2box_avail -1 ] == '\r' ) {	
 //	    display_status ( 
 //	        "Last received char is carriage return -> "
 //		"will check mailbox.");       		
-	    mailbox_clear_outbuf();
-	    mailbox_check();
+	    goto invoke_mailbox_check_io;
+	} 
+	else if (buf_hf2box[buf_hf2box_avail -1 ] == '\n' ) {	
+	    // this runs usually 
+	    /*
+	    display_status ( 
+	        "Last received char is newline -> "
+		"will check mailbox.");  
+	    */
+	    goto invoke_mailbox_check_io;		     		
+	} 
+	else 
 	    return;
-	}
-	if (buf_hf2box[buf_hf2box_avail -1 ] == '\n' ) {	
-//	    display_status ( 
-//	        "Last received char is newline -> "
-//		"will check mailbox.");       		
-	    mailbox_clear_outbuf();
-	    mailbox_check();
-	    return;
-	}
+	
+invoke_mailbox_check_io:
+/*
+ *  now we block ourselves:
+ */	
+	mailbox_input_waiting = 1;
+	mailbox_check_io();
+	return;
 }
 	    
 /* --------------------------------------------------------------------- */
-void mailbox_check () {
+
+void mailbox_check_io() {
 /*
  * Central mailbox control.
  * This function is invoked by 
@@ -213,63 +257,61 @@ void mailbox_check () {
  *
  * It is also invoked by an amtor slave connect (see msg.c)
  * because there might be no newline in the input at beginning.
- *
- *
  */
 	int i = 0;
 	
 	if (mailbox_on == 0) {
 	    display_status 
-	        ("mailbox_check: you did not activate the mailbox.");	
-	    mailbox_clear();
+	        ("mailbox_check_io: you did not activate the mailbox.");	
+	    mailbox_clear_allbufs();
 	    return;
 	}
-
 	if (mailbox_connected) {
-	// already connected before, so read -> write
+	// the 'usual case' is:
+	// mailbox was already connected before, so read -> write
 	//    display_status 
-	//        ("mailbox_check: Will send input buf to mailbox");	
+	//        ("mailbox_check_io: Will send input buf to mailbox");	
 	    if ( mailbox_test_port() ) {
 		mailbox_inbuf_2_port();
 	//    display_status 
-	//        ("mailbox_check: Will wait for answer from mailbox");	
+	//        ("mailbox_check_io: Will wait for answer from mailbox");	
 		mailbox_port_2_outbuf();
 		return;
 	    } else {
 	    display_status 
-	        ("mailbox_check: port to mailbox closed.");	
+	        ("mailbox_check_io: port to mailbox is closed.");	
 	    return;
 	    }
 	}
 
 	// now, if on but not connected, see if someone calls the mailbox.
 	// depends on mode....
-	switch (lastrx) {
+	switch (lastrxmsg) {
 	    case HFAPP_MSG_STATE_PACTOR_ARQ_SLAVECONNECT:
 		display_status 
-		    ("mailbox_check: we have been connected via Pactor Slave"); 
+		    ("mailbox_check_io: we have been connected via Pactor Slave"); 
 		display_status 
 		    ("by: %s", buf_hf2box); // + buf_hf2box_written); 
 		display_status 
 		    ("I will try to open the mailbox....");
-		if ( (i = mailbox_open()) < 0) {
+		if ( (i = mailbox_open_port()) < 0) {
 		    display_status 
-		        ("mailbox_check: mailbox could not be opened.\n"
+		        ("mailbox_check_io: mailbox could not be opened.\n"
 		        "Please see if xfbbd is started and\n"
 		        "port and ipadress options are given correctly.");
-			mailbox_clear();
+			mailbox_clear_allbufs();
 		        return;
 		}		    
-		mailbox_connected = 1;
+		mailbox_loggedin();
 		mailbox_clear_outbuf();
 		mailbox_port_2_outbuf();
 //		special case: discard the answer....
 		mailbox_clear_outbuf();
 //		display_status (  
-//			"mailbox_check: "
+//			"mailbox_check_io: "
 //			"buf_hf2box: %s", buf_hf2box);       
 //		display_status 
-//		    ("mailbox_check: pactor login."
+//		    ("mailbox_check_io: pactor login."
 //		    "I discarded F6FBB's greeting and call question.");
 		// user's call should stand in rx buffer now!!
 		mailbox_inbuf_2_port(); 
@@ -281,18 +323,18 @@ void mailbox_check () {
 	    case HFAPP_MSG_STATE_GTOR_ARQ_SLAVECONNECT:
 	    case HFAPP_MSG_STATE_AMTOR_ARQ_SLAVECONNECT:
 		display_status 
-		    ("mailbox_check: we have been connected via Amtor or Gtor"); 
+		    ("mailbox_check_io: we have been connected via Amtor or Gtor"); 
 		display_status 
 		    ("I will try to open the mailbox....");
-		if ( (i = mailbox_open()) < 0) {
+		if ( (i = mailbox_open_port()) < 0) {
 		    display_status 
-		        ("mailbox_check: mailbox could not be opened."
+		        ("mailbox_check_io: mailbox could not be opened."
 		        "Please see if xfbbd is started and\n"
 		        "port and ipadress options are given correctly.");
-			mailbox_clear();
+			mailbox_clear_allbufs();
 		        return;
 		}		    
-		mailbox_connected = 1;
+		mailbox_loggedin();
 		mailbox_clear_outbuf();
 		mailbox_port_2_outbuf();
 		return;
@@ -302,32 +344,31 @@ void mailbox_check () {
 	    case HFAPP_MSG_STATE_PACTOR_ARQ_DISCONNECT:
 	    case HFAPP_MSG_STATE_AMTOR_FEC_DISCONNECT:
 		display_status 
-		    ("mailbox_check: disconnect by remote station"); 
-		mailbox_connected = 0;
-		mailbox_close();
+		    ("mailbox_check_io: disconnect by remote station"); 
+		mailbox_loggedout();
 		return;
 	    
-	    case HFAPP_MSG_START_RTTY_RX:
+	    case HFAPP_MSG_STATE_RTTY_RX:
 		display_status 
-		    ("mailbox_check: QRZ in RTTY ?"); 
+		    ("mailbox_check_io: QRZ in RTTY ?"); 
 		goto goon;
 		break;	
 
 	    case HFAPP_MSG_START_PACTOR_STANDBY: 
 		display_status 
-		    ("mailbox_check: QRZ in Pactor FEC?"); 
+		    ("mailbox_check_io: QRZ in Pactor FEC?"); 
 		goto goon;
 		break;
 	
 	    case HFAPP_MSG_START_STANDBY: 
 		display_status 
-		    ("mailbox_check: QRZ in Pactor/Amtor/Gtor FEC ?"); 
+		    ("mailbox_check_io: QRZ in Pactor/Amtor/Gtor FEC ?"); 
 		goto goon;
 		break;
 	
 	    case HFAPP_MSG_STATE_PACTOR_FEC_CONNECT:
 		display_status 
-		    ("mailbox_check: QRZ in Pactor-FEC ?"); 
+		    ("mailbox_check_io: QRZ in Pactor-FEC ?"); 
 		goto goon;
 		break;
 	
@@ -335,45 +376,64 @@ void mailbox_check () {
 	    case HFAPP_MSG_STATE_AMTOR_SELFEC_RX:
 	    case HFAPP_MSG_STATE_AMTOR_COLFEC_RX:
 		display_status 
-		    ("mailbox_check: QRZ in Amtor-FEC ?"); 
+		    ("mailbox_check_io: QRZ in Amtor-FEC ?"); 
+		goto goon;
+		break;	
+
+	    case HFAPP_MSG_STATE_MT63_RX:
+		display_status 
+		    ("mailbox_check_io: QRZ in MT63 ?"); 
 		goto goon;
 		break;	
 
 	    default:
-		display_status("mailbox not yet implemented for this mode..."); 
+		display_status("mailbox_check_io: QRZ ? "); 
+		goto goon;
 	    break;
 	}
 	
 	goon:
-	/*look into the input buffer, check someone calling ?*/
+	/*look into the input buffer, check someone calling our call?*/
 	if (strstr(buf_hf2box, brag.call)) {
 	    display_status 
-		("mailbox_check: Was my call. Try to open mailbox....");
-	    if ( (i = mailbox_open()) < 0) {
+		("mailbox_check_io: Was my call. Try to open mailbox....");
+	    if ( (i = mailbox_open_port()) < 0) {
 		display_status 
-		("mailbox_check: Could not open port to mailbox.");
+		("mailbox_check_io: Could not open port to mailbox.");
 		return;
 	    }		    
-	    mailbox_connected = 1;
+	    mailbox_loggedin();
 //	    display_status 
-//		("mailbox_check: New connect.....");
+//		("mailbox_check_io: New connect.....");
 	    mailbox_clear_outbuf();
 	    mailbox_port_2_outbuf();
 	    return;
 	}
 	else {
 	    display_status 
-	        ("mailbox_check: This was not my call.");
-	    mailbox_clear();
+	        ("mailbox_check_io: This was not my call.");
+	    mailbox_clear_allbufs();
+	    mailbox_input_waiting = 0;
 	    return;
 	}
 }
 
 /* --------------------------------------------------------------------- */
 
-void mailbox_clear() {
+void mailbox_loggedin() {
+	mailbox_connected = 1;
+	beacon_suspend();
+//	display_status 
+//	    ("Beacon is suspended for time if mailbox connect");
+}
+
+/* --------------------------------------------------------------------- */
+
+void mailbox_clear_allbufs() {
 	mailbox_clear_inbuf();
 	mailbox_clear_outbuf();
+	mailbox_input_waiting = 0;
+	mailbox_output_waiting = 0;
 //	display_status ( "cleared mailbox input & output buffers.");
 	return;
 }
@@ -408,6 +468,11 @@ void mailbox_output(){
  * so that the remote user has time to switch from tx to rx 
  * and can get the message
  *
+ * in MT63 there is delay anyway from rempote's tx to our rx
+ * and: the keepalive msg does not come, 
+ * as there is rubbish received all the time
+ * so i call this function directly for MT63
+ *
  */
  	GtkText *txt;
 	int l = 0, w = 0;
@@ -427,7 +492,8 @@ void mailbox_output(){
 //	    buf_box2hf + buf_box2hf_written, w);
 	for(l = 0; l < w; l++) {
 	    v = buf_box2hf[buf_box2hf_written + l];
-	    edit_addchar(v);
+	    if (v == 10) edit_newline(); // cr instead of lf
+	    else edit_addchar(v);
 	}	
 	edit_newline();
 	buf_box2hf_written += w;
@@ -435,7 +501,7 @@ void mailbox_output(){
 //      /* check if write data has caught read data  */
 	if (buf_box2hf_written == buf_box2hf_avail) {
 //    	    mailbox_clear_outbuf();
-    	    mailbox_clear();	    
+    	    mailbox_clear_allbufs();	    
 	} else {
 	    // error without change of procedure
 	    // just start again for this version...
@@ -444,11 +510,11 @@ void mailbox_output(){
 		"I remove overflow of %d bytes of tx",
 	         buf_box2hf_avail - buf_box2hf_written);
 	}
-	mailbox_clear();	    
+	mailbox_clear_allbufs();	    
 //	    see if other side (f6fbb program) closed port
 	mailbox_test_port();
 	return;
-      }
+}
 
 /* --------------------------------------------------------------------- */
 
@@ -524,7 +590,7 @@ int connect_socket (int connect_port,
 
 /* --------------------------------------------------------------------- */
 
-int mailbox_open() {
+int mailbox_open_port() {
 
 	if (mailbox_fd > 0) {
 //	    display_status (  
@@ -559,7 +625,7 @@ int mailbox_open() {
 		"port and ipadress options are given correctly.",	
 		ipaddress, port);
 	    mailbox_on = 0;		
-	    mailbox_clear();
+	    mailbox_clear_allbufs();
 	    display_status 
 		( "I cleared buffers and switched mailbox mode off.");
 	    return(-1);
@@ -609,26 +675,26 @@ int mailbox_test_port () {
 	if (r == -1 && errno == EINTR) {
 	    display_status ("mailbox_test_port: error: select(...) == -1 && errno == EINTR");
 	    errprintf(SEV_WARNING, "mailbox_test_port: error: select(...) == -1 && errno == EINTR");
-	    mailbox_close();
+	    mailbox_loggedout();
 	    return 0;
 	}
 	if (r < 0) {
 	    display_status ("mailbox_test_port: error: select(...) < 0");
 	    errprintf(SEV_WARNING, "mailbox_test_port: error: select(...) < 0");
-   	    mailbox_close();
+   	    mailbox_loggedout();
     	    return 0;
 	}
 	if (FD_ISSET (mailbox_fd, &er)) {
 	    errno = 0;
 	    r = recv(mailbox_fd, &c, 1, MSG_OOB);
 	    if ( r < 1 ) {
-		display_status ("mailbox_test_port: "
-		"error in receiving exception message: %c", c );       
-		mailbox_close();
+//		display_status ("mailbox_test_port: "
+//		"error in receiving exception message: %c", c );       
+		mailbox_loggedout();
 		return 0;
 	    }
-	    display_status ("mailbox_test_port: "
-	    "box sends exception message: %c", c );       
+//	    display_status ("mailbox_test_port: "
+//	    "box sends exception message: %c", c );       
 	}		    
 	if (FD_ISSET (mailbox_fd, &rd)) {
 	    /*
@@ -650,15 +716,15 @@ int mailbox_test_port () {
 	// test
 	    r = recv(mailbox_fd, &c, 1, MSG_OOB);
 	    if ( r < 1 ) {
-		display_status ("mailbox_test_port: "
-		"error in receiving exception message: %c", c );       
-		//mailbox_close();
+//		display_status ("mailbox_test_port: "
+//		"error in receiving exception message: %c", c );       
+		//mailbox_loggedout();
 		//return 0;
 	    }
-	    display_status ("mailbox_test_port: "
-	    "box sends exception message: %c", c );       
+//	    display_status ("mailbox_test_port: "
+//	    "box sends exception message: %c", c );       
 	
-	    mailbox_close();
+	    mailbox_loggedout();
 	    return 0;
 	    /*
 	    and THAT WORKS WITH F6FBB, now auto-qrt when box quits.
@@ -670,7 +736,7 @@ int mailbox_test_port () {
 	    return 1;
 	}	
      	display_status ( "mailbox_test_port: unknown error.");       
-            mailbox_close();
+            mailbox_loggedout();
 	    return 0;
          
 }
@@ -716,13 +782,13 @@ void mailbox_inbuf_2_port () {
 	    if (r == -1 && errno == EINTR) {
 		display_status ( "mailbox_inbuf_2_port: error: select(...) == -1 && errno == EINTR");
 		errprintf(SEV_WARNING, "mailbox_inbuf_2_port: error: select(...) == -1 && errno == EINTR");
-		mailbox_close();
+		mailbox_loggedout();
 		return;
 	    }
 	    if (r < 0) {
 		display_status ( "mailbox_inbuf_2_port: error: select(...) < 0");
 		errprintf(SEV_WARNING, "mailbox_inbuf_2_port: error: select(...) < 0");
-   		mailbox_close();
+   		mailbox_loggedout();
     		return;
 	    }
 // WRITE FROM BUFFER TO BOX
@@ -741,7 +807,7 @@ void mailbox_inbuf_2_port () {
      		    display_status (  
 			"mailbox_inbuf_2_port: error while writing to mailbox."
 			"I will close it.");       
-            	    mailbox_close();
+            	    mailbox_loggedout();
 		    return;
         	} else {
 //		    display_status (  
@@ -771,7 +837,9 @@ void mailbox_inbuf_2_port () {
 /* --------------------------------------------------------------------- */
 
 void mailbox_port_2_outbuf () {
-// get f6fbb's answer via telnet and write it to my buffer box2hf
+/*
+ * get f6fbb's answer via telnet and write it to my buffer box2hf
+ */ 
 	static int n = 0;
 	int  r = 0, newtxbytes = 0;
        	fd_set rd; 
@@ -781,19 +849,16 @@ void mailbox_port_2_outbuf () {
 	    display_status (  
             	"mailbox_port_2_outbuf: Sorry, port %s:%d could not be opened.", 
 		ipaddress, port);
-	    mailbox_close();
+	    mailbox_loggedout();
 	    return;
 	}
-
 //	if (mailbox_fd > 0) {
 //	    display_status (  
 //		"mailbox_port_2_outbuf: box running at "
 //		"ip-address %s, port %d", ipaddress, port);
 //	}	
-
 	millisleep (350); //70
 //	display_status("slept 350 ms to give F6FBB time to think");
-
 	signal (SIGPIPE, SIG_IGN);
 	FD_ZERO (&rd);
 	FD_SET (mailbox_fd, &rd);
@@ -812,13 +877,13 @@ void mailbox_port_2_outbuf () {
 	    display_status 
 		( "mailbox_port_2_outbuf: error: select(...) == -1 && errno == EINTR");
 		errprintf(SEV_WARNING, "mailbox_port_2_outbuf: error: select(...) == -1 && errno == EINTR");
-		mailbox_close();
+		mailbox_loggedout();
 		return;
 	}
 	if (r < 0) {
 	    display_status ( "mailbox_port_2_outbuf: error: select(...) < 0");
 		errprintf(SEV_WARNING, "mailbox_port_2_outbuf: error: select(...) < 0");
-   		mailbox_close();
+   		mailbox_loggedout();
     		return;
 	}
 // READ FROM BOX & WRITE INTO BUFFER
@@ -831,11 +896,12 @@ void mailbox_port_2_outbuf () {
 	    if (newtxbytes == 0) {
 		display_status 
 		    ( "mailbox_port_2_outbuf: now nothing to read from mailbox");       
+		mailbox_input_waiting = 0;
 		return;
     	    } else if (newtxbytes < 0) {
 		display_status 
 	    	    ("mailbox_port_2_outbuf: error while reading from mailbox.");
-		mailbox_close();
+		mailbox_loggedout();
 	        return;
 	    } else { // read is positive 
     		/*
@@ -859,28 +925,42 @@ void mailbox_port_2_outbuf () {
 // 			moving forward "available" mark in buffer 
 		txwaitbytes += newtxbytes;
 		buf_box2hf_avail += newtxbytes;
+
+		// switch from input block to output-waiting-flag 
+		// to make debug easier
 		mailbox_output_waiting = 1;
-		    // from msg.c after some time
-		    // mailbox_output() will be called 
-		    // if mailbox_output_waiting = 1
+		mailbox_input_waiting = 0;
+
+		// from msg.c after some time ( = after a keepalive-msg)
+		// mailbox_output() will be called 
+		// if mailbox_output_waiting = 1
+		
+		/*
+		if (lastrxmsg == HFAPP_MSG_STATE_MT63_RX) {
+		    display_status("mailbox_output() called directly for mt63");
+		    mailbox_output();
+		}
+		*/
+		// mailbox_output() will be called 
+		// directly for mt63
 	    } 
 	} /* end of  "if (FD_ISSET (mailbox_fd, &rd))" block  */ 
-	return;
 }
 
 /* --------------------------------------------------------------------- */
 
-void mailbox_close() {
-	mailbox_clear();
+void mailbox_loggedout() {
+	mailbox_clear_allbufs();
 	SHUT_mailbox_fd 
 	display_status ( "Mailbox reset & standby ....");
 	mailbox_connected = 0;
+	beacon_restore();
 	mailbox_on = 1;
 //	means mailbox_on stays 1! Standby shall remain for automatic mailbox!!!
 //	can be set to 0 only by menu via function on_mailbox_activate 
-//	in callbacks.c
-	transmit("Mailbox closed -> disconnect! 73 de hfterm!\n");
-	qrt_pending = 1;
+//	in callbacks.c.
+//	transmit("Mailbox closed -> disconnect! 73 de hfterm!\n");
+	qrt(); // automatic qrt, this function is in rxtx.c
 	return;
 }
 
