@@ -71,7 +71,7 @@ __FILE__, __FUNCTION__,  __LINE__);
 #endif
 
 #ifndef MAXRX
-#define MAXRX 200
+#define MAXRX 2000
 #endif
 
 /* --------------------------------------------------------------------- */
@@ -209,6 +209,15 @@ void param_get(void)
 	params.gtor.retry = strtoul(gtk_entry_get_text(entry), NULL, 0);
 	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "gtortxdelay"));
 	params.gtor.txdelay = strtoul(gtk_entry_get_text(entry), NULL, 0);
+	/* MT63 parameters */
+	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_bandwidth_value"));
+	params.mt63.bandwidth = strtoul(gtk_entry_get_text(entry), NULL, 0);
+	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_integration"));
+	params.mt63.integration = strtoul(gtk_entry_get_text(entry), NULL, 0);
+	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_cwcall"));
+	strncpy(params.mt63.cwcall, gtk_entry_get_text(entry), sizeof(params.mt63.cwcall));
+	tog = GTK_TOGGLE_BUTTON(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_doubleinterleave"));
+	params.mt63.doubleinterleave = gtk_toggle_button_get_active(tog);
 }
 	
 //static 
@@ -216,7 +225,7 @@ void param_set(void)
 {
 	GtkEntry *entry;
 	GtkToggleButton *tog;
-	char buf[16];
+	char buf[32];
 
 	/* FSK parameters */
 	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "fskspacefreq"));
@@ -300,6 +309,19 @@ void param_set(void)
 	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "gtortxdelay"));
 	snprintf(buf, sizeof(buf), "%u", params.gtor.txdelay);
 	gtk_entry_set_text(entry, buf);
+	/* MT63 parameters */
+	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_bandwidth_value"));
+	snprintf(buf, sizeof(buf), "%u", params.mt63.bandwidth);
+	gtk_entry_set_text(entry, buf);
+	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_integration"));
+	snprintf(buf, sizeof(buf), "%u", params.mt63.integration);
+	gtk_entry_set_text(entry, buf);
+	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_cwcall"));
+	strncpy(buf, params.mt63.cwcall, sizeof(params.mt63.cwcall));
+	buf[sizeof(params.mt63.cwcall)] = 0;
+	gtk_entry_set_text(entry, buf);
+	tog = GTK_TOGGLE_BUTTON(gtk_object_get_data(GTK_OBJECT(wpar), "mt63_doubleinterleave"));
+	gtk_toggle_button_set_active(tog, params.mt63.doubleinterleave);
 }
 	
 //static 
@@ -352,6 +374,15 @@ void param_kernel(void)
 	msg.data.gpar.txdelay = htons(params.gtor.txdelay);
 	msg.data.gpar.retry = htons(params.gtor.retry);
 	msg_send(&msg);
+	/* MT63 parameters */
+	msg.hdr.type = htonl(HFAPP_MSG_SET_MT63PAR);
+	msg.hdr.err = htonl(ERR_NOERR);
+	msg.hdr.len = htonl(sizeof(msg.data.mt63par));
+	msg.data.mt63par.bandwidth = htons(params.mt63.bandwidth);
+	msg.data.mt63par.integration = htons(params.mt63.integration);
+	strncpy(msg.data.mt63par.cwcall, params.mt63.cwcall, sizeof(msg.data.mt63par.cwcall));
+	msg.data.mt63par.doubleinterleave = params.mt63.doubleinterleave;
+	msg_send(&msg);
 }
 
 void param_read()
@@ -359,15 +390,16 @@ void param_read()
 /* aus config-Datei gespeicherte params einlesen ------------------- */
 	FILE *conf;
 	conf = fopen("hf/hfterm.rc", "r");
-	if(conf == NULL)
-	{
+	if(conf == NULL) {
 	  display_status("Configuration File ~/hf/hfterm.rc can not be opened.");
 	  return;
 	}  
 	else	
-	display_status ("Configuration File ~/hf/hfterm.rc opened.");
-	if(fread(&params, sizeof(params), 1, conf) != 1)
+//	display_status ("Configuration File ~/hf/hfterm.rc opened.");
+	if(fread(&params, sizeof(params), 1, conf) != 1) {
 		display_status("Error while reading configuration file.");
+		return;
+	}
 	fclose(conf);	
 } 
 
@@ -382,8 +414,7 @@ void param_store()
 	  return;
 	}
 	else	
-		display_status
-		("Configuration File ~/hf/hfterm.rc opened.");
+	    //display_status("Configuration File ~/hf/hfterm.rc opened.");
 	if(fwrite(&params, sizeof(params), 1, conf) != 1)
 	{
 	  display_status
@@ -391,7 +422,7 @@ void param_store()
 	  return;
 	}
 	else	
-	//	display_status("Configuration stored in ~/hf/hfterm.rc.");
+//	display_status("Configuration stored in ~/hf/hfterm.rc.");
 	fclose(conf);	
 }
 
@@ -421,50 +452,207 @@ void rx_window_keep_small()
 void write_input(unsigned char *data, int datalen)
 {
 	GtkText *txt;
-	if (!data && datalen <= 0)
+	GtkEditable *entry;
+	gint pos;
+	int i, factor;
+	static int squelchcount = 0;
+	int squelchwait;
+	
+	if (!data && datalen <= 0) return;
+
+	/* squelch. The squelch_passed... flags are updated in spectrum.c */
+	if (lastrxmsg == HFAPP_MSG_STATE_MT63_RX) {
+	    if (!squelch_passed_mt36_500_1000) {
+		if (params.mt63.doubleinterleave) factor = 2;
+		else factor = 1;
+		squelchwait = (params.mt63.integration * factor) ; 
+		squelchcount++;
+		//display_status("MT63 squelch waits for %d units", squelchwait);
+		//display_status("MT63 squelch count %d units", squelchcount);
+		if (squelchcount > squelchwait) {
+		    /*
+		    display_status(
+			"MT63 signal remained weak for %d units -> squelched",
+			squelchwait);
+		    */
+		    return;
+		}
+	    } else squelchcount = 0;
+	}
+	/* for cw mode under construction */
+	/*
+	else if ((lastrxmsg == HFAPP_MSG_STATE_CW_RX) &&
+	    ( ! squelch_passed_cw)) {
+	    squelchwait = 10;
+	    squelchcount++;
+	    if (squelchcount > squelchwait ) {
+		display_status("cw signal remained weak for %3.1f s -> squelched",
+		params.mt63.integration * factor);
 		return;
+	    }
+	}
+	*/
+	else if (!squelch_passed_fsk) {
+		squelchwait = 0;
+		squelchcount++;
+		//display_status("FSK squelch waits for %d units", squelchwait);
+		//display_status("FSK squelch count %d units", squelchcount);
+		if (squelchcount > squelchwait) {
+		    /*
+		    display_status(
+			"FSK signal remained weak for %d units -> squelched",
+			squelchwait);
+		    */
+		    return;
+		}
+	} else squelchcount = 0;
+	
 	fbbtest = 0;
+	if (mailbox_on == 1) mailbox_input(data, datalen);
 	rx_window_keep_small();
 	txt = GTK_TEXT(gtk_object_get_data(GTK_OBJECT(wmain), "textmain"));
+
+/*
+the other squelch flags 
+extern int squelch_passed_mt36_1000_1500;
+extern int squelch_passed_mt36_1500_2500;
+could in future be processed here to feed mt63_bandwidth_autodetect() !
+*/
+
+/* carriage return handling : this i tried: 
+ * removes the ugly hook by which the radiofont expresses a 
+ * carriage-return. 
+ */
+
+/* works for rtty  and amtor : */
+/*
+	if (data[datalen - 1] == '\r') {
+	    //display_status ("datalen is %d, last is carriage return", datalen);
+	    data[datalen - 1] = ' '; 
+	}
+*/
+/* works for pactor : */ 
+/*
+	if (data[datalen - 2] == '\r') {
+	    //display_status ("datalen is %d, before last is carriage return", datalen);
+	    data[datalen - 2] = ' ';
+	}
+*/
+/* orig by Tom 
 	gtk_text_insert(txt, radiofont, NULL, NULL, data, datalen);
-	if (mailbox_on == 1) mailbox_input(data, datalen);
+*/
+	for (i = 0; i < datalen; i++) {
+	    if (data[i] == '\b') {
+	    	entry = GTK_EDITABLE
+		    (gtk_object_get_data(GTK_OBJECT(wmain), "textmain"));
+		pos = gtk_editable_get_position(entry);
+		if (pos > 0) {
+		    gtk_editable_delete_text(entry, pos-1, pos);
+		}
+	    } 
+	    else {
+		if (data[i] == '\r') {
+		    data[i] = ' ';
+		    /* removes the ugly hook by which the radiofont expresses a 
+		    carriage-return. */
+		}
+	    	gtk_text_insert(txt, radiofont, NULL, NULL, data+i, 1);
+	    }
+	}
 }
 
 void write_output(unsigned char *data, int datalen)
 {
-    GtkText *txt;
-    GdkColor txfg, txbg;
+	int i;
+	GtkText *txt;
+	GtkEditable *entry;
+	gint pos;
+	GdkColor txfg, txbg;
 
-    	 txfg.pixel = 0;
-	 txfg.red = 65535;	
-	 txfg.green = 0;
-	 txfg.blue = 65535;
+	txfg.pixel = 0;
+	txfg.red = 65535;	
+	txfg.green = 0;
+	txfg.blue = 65535;
 	/* pink */
 
-	 txbg.pixel = 0;
-	 txbg.red = 55000;
-	 txbg.green = 65535;
-	 txbg.blue = 55000;
+	txbg.pixel = 0;
+	txbg.red = 55000;
+	txbg.green = 65535;
+	txbg.blue = 55000;
 	/* light green */
 	
-    if (!data && datalen <= 0) {
-	display_status ("hfterm/src/main.c: no data, len 0");
-	return;
-    }
-    if (!data ) {
-	display_status ("hfterm/src/main.c: no data");
-	return;
-    }
-    if ( datalen <= 0) {
-	display_status ("hfterm/src/main.c: len 0");
-	return;
-    }
-    fbbtest = 0;
-    rx_window_keep_small();
-    txt = GTK_TEXT(gtk_object_get_data(GTK_OBJECT(wmain), "textmain"));
-    gtk_text_insert(txt, radiofont, 
+	if (!data && datalen <= 0) {
+	    display_status ("hfterm/src/main.c: no data, len 0");
+	    return;
+	}
+	if (!data ) {
+	    display_status ("hfterm/src/main.c: no data");
+	    return;
+	}
+	if ( datalen <= 0) {
+	    display_status ("hfterm/src/main.c: len 0");
+	    return;
+	}
+	fbbtest = 0;
+	rx_window_keep_small();
+	txt = GTK_TEXT(gtk_object_get_data(GTK_OBJECT(wmain), "textmain"));
+
+	if (radiofont == NULL) {
+	    if ((radiofont = gdk_font_load("7x13")) == NULL)
+		display_status("simple font 7x13 could not be loaded.");
+	}
+
+	    /*    
+	    newline only at a line:
+	    pactor: datalen = 2
+	    all other: datalen = 1
+	    
+	    5 letters and newline in a line:
+	    pactor: datalen = 7
+	    all other: datalen = 1
+	    */
+
+	/*  with the 7x13 font 
+	    the carriage return (\r) is printed as a hook, not looking nice!
+	*/
+	    /* works for rtty  and amtor !! */
+/*
+	if (data[datalen - 1] == '\r') {
+	    //display_status ("datalen is %d, last is carriage return", datalen);
+	    data[datalen - 1] = ' '; 
+	}
+*/
+	    /* works for pactor !! */ 
+/*
+	if (data[datalen - 2] == '\r') {
+	    //display_status ("datalen is %d, before last is carriage return", datalen);
+	    data[datalen - 2] = ' ';
+	}
+*/
+	    /* orig by Tom, modified by Gnther */
+/*
+	gtk_text_insert(txt, radiofont, 
 //    &(GTK_WIDGET(txt)->style->fg[GTK_WIDGET_STATE(GTK_WIDGET(txt))]), 
-    &txfg, &txbg, data, datalen);
+	&txfg, &txbg, data, datalen);
+*/
+	for (i = 0; i < datalen; i++) {
+	    if (data[i] == '\b') {
+	    	entry = GTK_EDITABLE
+		    (gtk_object_get_data(GTK_OBJECT(wmain), "textmain"));
+		pos = gtk_editable_get_position(entry);
+		if (pos > 0) {
+		    gtk_editable_delete_text(entry, pos-1, pos);
+		}
+	    } 
+	    else {
+		if (data[i] == '\r') {
+		    data[i] = ' ';
+		    /* removes the ugly hook by which the radiofont expresses a 
+		    carriage-return. */
+		}
+	    	gtk_text_insert(txt, radiofont, &txfg, &txbg, data+i, 1);
+	    }
+	}
 }
 
 void start_write_mailboxtest()
@@ -554,6 +742,7 @@ void edit_newline(void)
 //	see below
 //	entry = GTK_ENTRY(gtk_object_get_data(GTK_OBJECT(wmain), "textedit"));
 //	gtk_entry_set_text(entry, "");
+
 	msg.data.b[0] = '\r';
 	msg.data.b[1] = '\n';
         msg.hdr.type = htonl(HFAPP_MSG_DATA_TRANSMIT);
@@ -735,7 +924,7 @@ void brag_read()
 	  return;
 	}  
 	else	
-	    display_status("bragfile ~/hf/hfterm.brag opened.");
+//	    display_status("bragfile ~/hf/hfterm.brag opened.");
 	if(fread(&brag, sizeof(brag), 1, bragfile) != 1)
 		display_status("Error while reading bragfile.");
 	fclose(bragfile);	
@@ -747,10 +936,14 @@ void brag_store()
 /* - Persnliche Daten speichern -------------------------------------*/
 	FILE *bragfile;
 	bragfile = fopen("hf/hfterm.brag", "w");
-	if(bragfile == NULL)
-		display_status(	"bragfile ~/hf/hfterm.brag can not be opened.\n");
-	if(fwrite(&brag, sizeof(brag), 1, bragfile) != 1)
-		display_status(	"Error while writing bragfile ~/hf/hfterm.brag !\n");
+	if(bragfile == NULL) {
+	    display_status("bragfile ~/hf/hfterm.brag can not be opened.\n");
+	    return;
+	}
+	if(fwrite(&brag, sizeof(brag), 1, bragfile) != 1) {
+	    display_status("Error while writing bragfile ~/hf/hfterm.brag !\n");
+	    return;
+	}
 	fclose(bragfile);	
 	return;
 }
@@ -777,13 +970,12 @@ void init(void)
 	char *bp1;
 	const char *bp2;
 	int kernel_running = 0;
-	struct hfapp_msg msg;
+	//struct hfapp_msg msg;
 
 	system("cd");
 	system("if ! [ -d hf ] ; then mkdir hf; cp -ruv /usr/share/hf/hf-examplefiles/* hf; fi");
-	sprintf(versioninfo,  "hfterm %s by Tom Sailer, HB9JNX/AE4WA,\n"
-		"Ralf-Axel Krause, DF3JRK,\nGnther Montag, DL4MGE", 
-		VERSION);
+	sprintf(versioninfo,  "hfterm %s by Tom Sailer, Axel Krause, "
+	    "Gnther Montag, Pawel Jalocha et al. ", VERSION);
 	display_status(versioninfo);
 	if ((fd_krnl = socket(PF_UNIX, SOCK_STREAM, 0)) < 0)
 		errstr(SEV_FATAL, "socket");
@@ -794,13 +986,13 @@ void init(void)
 		close(fd_krnl);
 		msgpfd.fd = fd_krnl = -1;
 		display_status("hfkernel not started!\n"
-		    "May be You have to adapt script /usr/bin/hf or \n"
-		    "the configuration file /etc/hf.conf fist. \n"
-		    "e.g. correct the ttyS.. (serial port for PTT)  entry.\n"
+		    "Maybe you have to adapt /etc/hf.conf first. \n"
+		    "(e.g. correct the ttyS.. (serial port for PTT)  entry.)\n"
 		    "See F1 or /usr/share<doc/>(packages/)/hf/HF-HOWTO for help.");
 	} else {
 		kernel_running = 1;
-		g_source_add(G_PRIORITY_HIGH, FALSE, &poll_funcs, NULL, NULL, NULL);
+		g_source_add(G_PRIORITY_HIGH, FALSE, 
+		    &poll_funcs, NULL, NULL, NULL);
 		msgpfd.fd = fd_krnl;
 		msgpfd.events = G_IO_IN;
 		msgpfd.revents = 0;
@@ -808,6 +1000,7 @@ void init(void)
 	}
 	
 /* Falls keine config-Datei gefunden wird: params vorbelegen------- */
+/* if binary per-user config ~/hfrc not fount, preset params ------ */
 	memset(&params, 0, sizeof(params));
 	params.gtor.txdelay = 30;
 	params.gtor.retry = 30;
@@ -820,7 +1013,6 @@ void init(void)
 	params.amtor.txdelay = 30;
 	params.amtor.retry = 30;
 	params.rtty.baud = 45;
-	
 	set_fsk_freq(FREQ_MARK, FREQ_SPACE);
 
 	strncpy(params.gtor.mycall, mycall, sizeof(params.gtor.mycall));
@@ -839,7 +1031,11 @@ void init(void)
 	}
 	strncpy(params.amtor.mycall, buf, sizeof(params.amtor.mycall));
 	strncpy(params.amtor.selfeccall, buf, sizeof(params.amtor.selfeccall));
-	
+	params.mt63.bandwidth        = 1000;
+	params.mt63.integration      = 32;
+	strncpy(params.mt63.cwcall, "MT63", sizeof(params.mt63.cwcall));
+	params.mt63.doubleinterleave = 0;	
+
 	param_read();	
 	fixtext_read();
 	brag_read();
@@ -850,16 +1046,17 @@ void init(void)
 
 	if ((radiofont = gdk_font_load("7x13")) == NULL)
 	    display_status("simple font 7x13 could not be loaded.");
-		
+/*	    
 	if(kernel_running) {
 	    msg.hdr.err = htonl(ERR_NOERR);
 	    msg.hdr.len = htonl(0);
 	    msg.hdr.type = htonl(HFAPP_MSG_START_STANDBY);
 	    msg_send(&msg);
-	    display_status("starting with STANDBY FOR PACTOR - AMTOR - GTOR ...");
-	    lastrx = HFAPP_MSG_START_STANDBY;
-	    userrx();
+	    display_status("start with STANDBY FOR PACTOR-AMTOR- GTOR...");
+	    lastrxcmd = HFAPP_MSG_START_STANDBY;
+	    way = RX;
 	}
+*/
 }
 
 /* ----------------------------------------------------------------- */
@@ -867,22 +1064,17 @@ void init(void)
 /* ------------------------------------------------------------------ */
 void finit(void)
 {
+	/*is called from callbacks.c */
 	errprintf (SEV_INFO,"hfterm: 73 & hpe cuagn sn !! \n");        
 	display_status("\n73 !!! by hfterm !");        
 	gtk_main_quit();
-//	sleep(1);
-//	D
 /* - Rx-Text-Rest speichern ------------------------------------------*/
-//	D
 	rx_routine_store_rest();
 /* - Fix - Text speichern --------------------------------------------*/
-//	D
 	fixtext_store();
 /* - Config-Datei speichern ------------------------------------------*/
-//	D
 	param_store();
 /* - Log-Datei speichern ---------------------------------------------*/
-//	D
 	log_store();
 }
 
@@ -892,7 +1084,7 @@ void finit(void)
 int main(int argc, char *argv[])
 {
         int c, err = 0;
-//	auskommentiert weil laut compiler "statement with no effect"
+//	compiler:  "statement with no effect"
 //	bindtextdomain(PACKAGE, PACKAGE_LOCALE_DIR);
 //	textdomain(PACKAGE);
 //		
@@ -955,7 +1147,6 @@ int main(int argc, char *argv[])
 
  	init();
 	gtk_main();
-	//finit();
 	exit(0);
 }
 
