@@ -48,6 +48,9 @@ create_wmain (void)
   GtkWidget *trennlinie9;
   GtkWidget *rtty_receive;
   GtkWidget *rtty_transmit;
+  GtkWidget *menulinemt63;
+  GtkWidget *mt63_rx;
+  GtkWidget *mt63_tx;
   GtkWidget *utilities;
   GtkWidget *utilities_menu;
   GtkAccelGroup *utilities_menu_accels;
@@ -132,7 +135,8 @@ create_wmain (void)
   GtkWidget *A_CFEC_button;
   GtkWidget *A_SFEC_button;
   GtkWidget *RTTY_RX_button;
-  GtkWidget *RTTY_TX_button;
+//  GtkWidget *RTTY_TX_button;
+  GtkWidget *MT63_button;
 //  GtkWidget *parabutton;
 
   GtkWidget *scrolledwindow40;
@@ -146,7 +150,7 @@ create_wmain (void)
   GtkWidget *textstatus;
   GtkAccelGroup *accel_group;
   GtkTooltips *tooltips;
-   char versiontitle[64];
+   char versiontitle[128];
 
   tooltips = gtk_tooltips_new ();
   accel_group = gtk_accel_group_new ();
@@ -155,7 +159,9 @@ create_wmain (void)
   gtk_widget_set_name (wmain, "wmain");
   gtk_object_set_data (GTK_OBJECT (wmain), "wmain", wmain);
   
-  sprintf(versiontitle, "hf %s - pactor amtor gtor rtty program & f6fbb mailbox interface", VERSION);
+  sprintf(versiontitle, 
+      "hf %s - pactor amtor gtor rtty mt63 program with mailbox interface", 
+      VERSION);
 
   gtk_window_set_title (GTK_WINDOW (wmain), _(versiontitle));
   gtk_window_set_position (GTK_WINDOW (wmain), GTK_WIN_POS_CENTER);
@@ -510,8 +516,10 @@ create_wmain (void)
   gtk_container_add (GTK_CONTAINER (mode_menu), trennlinie9);
   gtk_widget_set_sensitive (trennlinie9, FALSE);
 
-  rtty_receive = gtk_radio_menu_item_new_with_label (mode_menu_group, _("RTTY Receive"));
-  mode_menu_group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (rtty_receive));
+  rtty_receive = gtk_radio_menu_item_new_with_label 
+      (mode_menu_group, _("RTTY Receive"));
+  mode_menu_group = gtk_radio_menu_item_group 
+      (GTK_RADIO_MENU_ITEM (rtty_receive));
   gtk_widget_set_name (rtty_receive, "rtty_receive");
   gtk_widget_ref (rtty_receive);
   gtk_object_set_data_full (GTK_OBJECT (wmain), "rtty_receive", rtty_receive,
@@ -519,23 +527,66 @@ create_wmain (void)
   gtk_widget_show (rtty_receive);
   gtk_container_add (GTK_CONTAINER (mode_menu), rtty_receive);
   gtk_widget_add_accelerator (rtty_receive, "activate", accel_group,
-                              GDK_F11, 0,
-                              GTK_ACCEL_VISIBLE);
-  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (rtty_receive), TRUE);
+      GDK_F11, 0,  GTK_ACCEL_VISIBLE);
+  gtk_check_menu_item_set_show_toggle 
+      (GTK_CHECK_MENU_ITEM (rtty_receive), TRUE);
 
-  rtty_transmit = gtk_radio_menu_item_new_with_label (mode_menu_group, _("RTTY Transmit"));
-  mode_menu_group = gtk_radio_menu_item_group (GTK_RADIO_MENU_ITEM (rtty_transmit));
+  rtty_transmit = gtk_radio_menu_item_new_with_label 
+      (mode_menu_group, _("RTTY Transmit"));
+  mode_menu_group = gtk_radio_menu_item_group 
+      (GTK_RADIO_MENU_ITEM (rtty_transmit));
   gtk_widget_set_name (rtty_transmit, "rtty_transmit");
   gtk_widget_ref (rtty_transmit);
   gtk_object_set_data_full (GTK_OBJECT (wmain), "rtty_transmit", rtty_transmit,
                             (GtkDestroyNotify) gtk_widget_unref);
   gtk_widget_show (rtty_transmit);
   gtk_container_add (GTK_CONTAINER (mode_menu), rtty_transmit);
+/* now needed for mt63
   gtk_widget_add_accelerator (rtty_transmit, "activate", accel_group,
-                              GDK_F12, 0,
-                              GTK_ACCEL_VISIBLE);
+      GDK_F12, 0, GTK_ACCEL_VISIBLE);
+*/
   gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (rtty_transmit), TRUE);
 
+  menulinemt63 = gtk_menu_item_new ();
+  gtk_widget_set_name (menulinemt63, "menulinemt63");
+  gtk_widget_ref (menulinemt63);
+  gtk_object_set_data_full (GTK_OBJECT (wmain), "menulinemt63", menulinemt63,
+                            (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (menulinemt63);
+  gtk_container_add (GTK_CONTAINER (mode_menu), menulinemt63);
+  gtk_widget_set_sensitive (menulinemt63, FALSE);
+
+  mt63_rx = gtk_radio_menu_item_new_with_label 
+      (mode_menu_group, _("MT63 Receive"));
+  mode_menu_group = gtk_radio_menu_item_group 
+      (GTK_RADIO_MENU_ITEM (mt63_rx));
+  gtk_widget_set_name (mt63_rx, "mt63_rx");
+  gtk_widget_ref (mt63_rx);
+  gtk_object_set_data_full (GTK_OBJECT (wmain), "mt63_rx", mt63_rx,
+                            (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (mt63_rx);
+  gtk_container_add (GTK_CONTAINER (mode_menu), mt63_rx);
+  gtk_widget_add_accelerator (mt63_rx, "activate", accel_group,
+      GDK_F12, 0,  GTK_ACCEL_VISIBLE);
+  gtk_check_menu_item_set_show_toggle 
+      (GTK_CHECK_MENU_ITEM (mt63_rx), TRUE);
+
+  mt63_tx = gtk_radio_menu_item_new_with_label 
+      (mode_menu_group, _("MT63 Transmit"));
+  mode_menu_group = gtk_radio_menu_item_group 
+      (GTK_RADIO_MENU_ITEM (mt63_tx));
+  gtk_widget_set_name (mt63_tx, "mt63_tx");
+  gtk_widget_ref (mt63_tx);
+  gtk_object_set_data_full (GTK_OBJECT (wmain), "mt63_tx", mt63_tx,
+                            (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (mt63_tx);
+  gtk_container_add (GTK_CONTAINER (mode_menu), mt63_tx);
+/* 
+  gtk_widget_add_accelerator (mt63_tx, "activate", accel_group,
+      GDK_F12, 0, GTK_ACCEL_VISIBLE);
+*/
+  gtk_check_menu_item_set_show_toggle (GTK_CHECK_MENU_ITEM (mt63_tx), TRUE);
+
   utilities = gtk_menu_item_new_with_label (_("Utilities"));
   gtk_widget_set_name (utilities, "utilities");
   gtk_widget_ref (utilities);
@@ -1189,7 +1240,7 @@ create_wmain (void)
   gtk_container_set_border_width (GTK_CONTAINER (A_SFEC_button), 3);
   gtk_tooltips_set_tip (tooltips, A_SFEC_button, _("calls the Amtor selective FEC call (see Parameter Menu, Shift-P)"), NULL);
 
-  RTTY_RX_button = gtk_button_new_with_label (_("11: RTTY RX"));
+  RTTY_RX_button = gtk_button_new_with_label (_("11: RTTY"));
   gtk_widget_set_name (RTTY_RX_button, "RTTY_RX_button");
   gtk_widget_ref (RTTY_RX_button);
   gtk_object_set_data_full (GTK_OBJECT (wmain), "RTTY_RX_button", RTTY_RX_button,
@@ -1199,6 +1250,7 @@ create_wmain (void)
   gtk_container_set_border_width (GTK_CONTAINER (RTTY_RX_button), 3);
   gtk_tooltips_set_tip (tooltips, RTTY_RX_button, _("RTTY RX. With Alt-U, -L, -F you can toggle upper, lower, figure case.\n45 baud is default for ham radio. You can also try other rates (see parameter menu Shift-P) for wx stations etc."), NULL);
 
+/*
   RTTY_TX_button = gtk_button_new_with_label (_("12: RTTY TX"));
   gtk_widget_set_name (RTTY_TX_button, "RTTY_TX_button");
   gtk_widget_ref (RTTY_TX_button);
@@ -1208,10 +1260,18 @@ create_wmain (void)
   gtk_box_pack_start (GTK_BOX (vboxmode), RTTY_TX_button, FALSE, FALSE, 0);
   gtk_container_set_border_width (GTK_CONTAINER (RTTY_TX_button), 3);
   gtk_tooltips_set_tip (tooltips, RTTY_TX_button, _("RTTY Transmit. 45 baud is default. \nIn Parameter menu (Shift-P) you can change baudrate and mark&space and invert."), NULL);
-
-
+*/
+  MT63_button = gtk_button_new_with_label (_("12: MT63"));
+  gtk_widget_set_name (MT63_button, "MT63_button");
+  gtk_widget_ref (MT63_button);
+  gtk_object_set_data_full (GTK_OBJECT (wmain), "MT63_button", MT63_button,
+                            (GtkDestroyNotify) gtk_widget_unref);
+  gtk_widget_show (MT63_button);
+  gtk_box_pack_start (GTK_BOX (vboxmode), MT63_button, FALSE, FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (MT63_button), 3);
+  gtk_tooltips_set_tip (tooltips, MT63_button, _("Pawel Jalocha's MT63.\nIn Parameter menu (Shift-P) you can change bandwidth, double-interleave, integration. "), NULL);
 /*  
-   put it out because of symmetry and so that F1 - F12 is consistent
+   took it out because of symmetry and so that F1 - F12 is consistent
    parabutton = gtk_button_new_with_label (_("Parameters"));
   gtk_widget_set_name (parabutton, "parabutton");
   gtk_widget_ref (parabutton);
@@ -1398,7 +1458,7 @@ create_wmain (void)
                               GDK_F9, GDK_SHIFT_MASK,
                               GTK_ACCEL_VISIBLE);
 
-  Fix_button10 = gtk_button_new_with_label (_("10: wx"));
+  Fix_button10 = gtk_button_new_with_label (_("10: mailbox"));
   gtk_widget_set_name (Fix_button10, "Fix_button10");
   gtk_widget_ref (Fix_button10);
   gtk_object_set_data_full (GTK_OBJECT (wmain), "Fix_button10", Fix_button10,
@@ -1564,6 +1624,12 @@ create_wmain (void)
   gtk_signal_connect (GTK_OBJECT (rtty_transmit), "activate",
                       GTK_SIGNAL_FUNC (on_rtty_transmit_activate),
                       NULL);
+  gtk_signal_connect (GTK_OBJECT (mt63_rx), "activate",
+                      GTK_SIGNAL_FUNC (on_mt63_rx_activate),
+                      NULL);
+  gtk_signal_connect (GTK_OBJECT (mt63_tx), "activate",
+                      GTK_SIGNAL_FUNC (on_mt63_tx_activate),
+                      NULL);
   gtk_signal_connect (GTK_OBJECT (frequency_spectrum), "activate",
                       GTK_SIGNAL_FUNC (on_frequency_spectrum_activate),
                       NULL);
@@ -1646,10 +1712,15 @@ create_wmain (void)
   gtk_signal_connect (GTK_OBJECT (RTTY_RX_button), "clicked",
                       GTK_SIGNAL_FUNC (on_rtty_receive_activate),
                       NULL);
+/*		      
   gtk_signal_connect (GTK_OBJECT (RTTY_TX_button), "clicked",
                       GTK_SIGNAL_FUNC (on_rtty_transmit_activate),
                       NULL);
-
+*/
+  gtk_signal_connect (GTK_OBJECT (MT63_button), "clicked",
+                      GTK_SIGNAL_FUNC (on_mt63_rx_activate),
+                      NULL);
+		      
   gtk_signal_connect (GTK_OBJECT (Fix_button1), "clicked",
                       GTK_SIGNAL_FUNC (on_Fix_button1_clicked),
                       NULL);
