@@ -40,23 +40,27 @@ __FILE__, __FUNCTION__,  __LINE__);
 
 /* --------------------------------------------------------------------- */
 
-int autorx_on = 0, autotx_on = 0;
-int beacon_on = 0, beaconcount = 0, fixbeacon = 0;
-int qrt_pending = 0;
+int autorx_on = 0;
+int beacon_on = 0, beacon_was_on = 0, beaconcount = 0, fixbeacon = 0;
+int lastrxcmd = 0, lastrxmsg = 0, lasttxcmd = 0, lasttxmsg = 0;
+int qrt_pending = 0, arq;
 char specialfile[256], rxfilehead[256], rxfilefoot[256]; 
 char beaconbuffer[MAXKEY], keytext[MAXKEY];
 const char *fixmagic = 
 "	* * * * * * *	YOUR MAGIC KEYS: 	* * * * * * * \n"
-"[B] 		will transmit the text as BEACON. (Stop it with <Alt>b.)\n"
+"[B] will transmit the text as BEACON. (Stop it with <Alt>b.)\n"
 "[MYCALL] [OP] [QTH] [LOC] [RIG] [PWR] [ANT] [WWW]\n"
-"		will be replaced by your entries from 'Personal Edit'.\n"
-"[TIME]		will print a timestamp.\n"
+"will be replaced by your entries from 'Personal Edit'.\n"
+"[TIME]	will print a timestamp.\n"
 "[ACALL] (Amtor), [PCALL] = [CALL] (Pactor + RTTY), [GCALL] (Gtor)\n"
-"		is your QSO-Partner's call, taken from 'Parameters'.\n"
+"is your QSO-Partner's call, taken from 'Parameters'.\n"
+"[AMYCALL] (Amtor), [PMYCALL] = [CALL] (Pactor + RTTY), [GMYCALL] (Gtor)\n"
+"is your own call, taken from 'Parameters'.\n"
 "[LTIME] [LCALL] [LNAME] [LQTH] [LRSTIN] [LRSTOUT] [LNOTES] [LMODE] [LBAND]\n"
-"		will be replaced by the corresponding fielod of last log entry.\n"
-"You can use 'Strg-X, Strg-C, Strg-V to cut, copy and insert from one window to another.\n"
-"To use the fixtexts, press Shift-F<number> or click the text macro buttons. Have a lot of fun!";
+"will be replaced by the corresponding fielod of last log entry.\n"
+"You can use 'Strg-X, Strg-C, Strg-V to cut, copy and insert.\n"
+"To use the fixtexts, press Shift-F<number> or click the right buttons.\n"
+"* * * *  Have a lot of fun!  * * * * ";
 FILE *rxfile;
 
 /* --------------------------------------------------------------- */
@@ -120,9 +124,14 @@ void textinsert(char *filename, GtkText *text)
   {
   	FILE *fi;
   	char buf[16];
-  	if ((radiofont = gdk_font_load("7x13")) == NULL)
-	    display_status("simple font 7x13 could not be loaded.");
-  	fi = fopen(filename, "r");
+  	static int radiofont_loaded = 0;
+	
+	if (! radiofont_loaded ) {
+	    if ((radiofont = gdk_font_load("7x13")) == NULL)
+		display_status("simple font 7x13 could not be loaded.");
+  	    else radiofont_loaded = 1;
+	}
+	fi = fopen(filename, "r");
   	if(fi == NULL)
   	  {
   	    display_status( "file %s can not be opened.\n", filename);
@@ -161,7 +170,7 @@ void parse(char* magic, char* bragitem)
 	  strcat(a, c + strlen(magic));
 //	  display_status( "\n\na nach 2. Teil\n%s", a);
 	  strcpy(keytext, a);
-//	  printf("\nkeytext:\n%s", keytext);
+	  printf("\nkeytext:\n%s", keytext);
 	}
     }
     return;
@@ -193,8 +202,11 @@ void fixtext_send(int fixnr)
 	  strcpy(keytext, fixtext);
 	  parse("[CALL]", params.pactor.destcall);
           parse("[PCALL]", params.pactor.destcall);
+	  parse("[PMYCALL]", params.pactor.mycall);
           parse("[ACALL]", params.amtor.destcall);
+	  parse("[AMYCALL]", params.amtor.mycall);
           parse("[GCALL]", params.gtor.destcall);
+	  parse("[GMYCALL]", params.gtor.mycall);
           parse("[MYCALL]", brag.call);
           parse("[OP]", brag.op);
           parse("[QTH]", brag.qth);
@@ -217,19 +229,23 @@ void fixtext_send(int fixnr)
           	display_status("I replaced magic keys [L...] from log entry Nr. %d", lb.logsize);
           }
           else {
+/*
           	display_status
 		    ("did not parse magic keys from macro concerning log,\n"
           	    "because no log entry was specified");
+*/
           }
 	  if ( strstr(keytext, "[B]") ) {
 	      display_status("[B] magic key in fixtext -> beacon");
               parse("[B]", " ");
 	      fixbeacon = i;
+	      beacon_file_prepared = 0;
+	      // fixtext beacon beats file beacon
 	      beacon_on = 1;
 	      autotx();     
 	      autorx_on = 1; 
-	     // beacon_fixtext_prepare();
-	  }
+	  } else 
+	  autotx();
 /*
 //	no use now, autotx / rx is now default
 	  if ( strstr(keytext, "[TX]") ) {
@@ -245,7 +261,7 @@ void fixtext_send(int fixnr)
 */
 	  txt = GTK_TEXT(gtk_object_get_data(GTK_OBJECT(wmain), "textedit"));
 	  gtk_text_insert(txt, radiofont, NULL, NULL, keytext, strlen(keytext));
-	  
+
 	  display_status("transmitting fixtext %hu",  i);
 	  edit_newline();
 	  for(l = 0; l < strlen(keytext); l++)
@@ -266,24 +282,23 @@ void fixtext_read()
 	FILE *fix;
 	int i; 
 	char fixfilename[32], fixtextname[8], buf[16];
-	for (i = 1; i < 13; i++)
-	{
-		sprintf(fixfilename, "hf/fix.%02hu", i);
-		sprintf(fixtextname, "text%hu", i);
-		fix = fopen(fixfilename, "r");
-		if(fix == NULL)
-		{
-		  display_status( "fixtextfile %s can not be opened.\n", fixfilename);
-		  break;
-		}
-		
-		while ( !feof(fix) )
-		{
-			memset(buf, 0, sizeof(buf));
-			fgets(buf, 15, fix);
-			gtk_text_insert ((GTK_TEXT(gtk_object_get_data(GTK_OBJECT(Wfixtext), fixtextname))) , NULL, NULL, NULL, buf, -1);
-		}
-		fclose(fix);				
+	for (i = 1; i < 13; i++) {
+	    sprintf(fixfilename, "hf/fix.%02hu", i);
+	    sprintf(fixtextname, "text%hu", i);
+	    fix = fopen(fixfilename, "r");
+	    if(fix == NULL) {
+		display_status( "fixtextfile %s can not be opened.\n", fixfilename);
+		break;
+	    }
+	    while ( !feof(fix) ) {
+		memset(buf, 0, sizeof(buf));
+		fgets(buf, 15, fix);
+		gtk_text_insert 
+		    ((GTK_TEXT(gtk_object_get_data
+		    (GTK_OBJECT(Wfixtext), fixtextname))) , 
+		    radiofont, NULL, NULL, buf, -1);
+	    }
+	    fclose(fix);				
 	}
 }	
   
@@ -354,7 +369,30 @@ void file_send()
 
 /* --------------------------------------------------------------- */
 
-void beacon_file_prepare()
+void beacon_suspend() {
+	if (beacon_on) {
+	    beacon_on = 0;
+	    beacon_was_on = 1;
+	    display_status 
+	        ("Beacon is suspended during time of connect.");
+	}
+}
+
+/* --------------------------------------------------------------- */
+
+void beacon_restore() {
+	if (beacon_was_on) {
+	    beacon_on = 1;
+	    beacon_was_on = 0;
+	    display_status 
+	        ("Beacon was running before -> I start it again.\n"
+		"You can stop the beacon by <Alt>B.");
+	}
+}
+
+/* --------------------------------------------------------------- */
+
+int beacon_file_prepare()
 {
 /* prepare beacon with fileselection dialog ----------------------------------------------*/
 	FILE *beaconfile;
@@ -367,11 +405,11 @@ void beacon_file_prepare()
 	beaconfile = fopen(specialfile, "r");
 	if(beaconfile == NULL) {
 	    display_status("beacon file %s can not be opened.", specialfile);
-	    return;
+	    return 0; // error
 	}
 	display_status
 	    ("will read (part of) beaconfile %s into buffer", specialfile);
-	display_status("empty buffer contains: \n%s", beaconbuffer);
+	//display_status("empty buffer contains: \n%s", beaconbuffer);
 	
 	while (buffercount < sizeof(beaconbuffer) - 1) {
 	    c = fgetc(beaconfile);
@@ -381,17 +419,13 @@ void beacon_file_prepare()
 	    }
 	    else break;
     	}
-//	while ( !feof(beaconfile) ){
-//	fgets(beaconbuffer, sizeof(beaconbuffer), beaconfile);
-//	}
 	fclose(beaconfile);				
-	display_status
-	    ("have read (part of) beaconfile %s into buffer", specialfile);
-	display_status("buffer contains now: \n%s", beaconbuffer);
+	//display_status
+	//    ("have read (part of) beaconfile %s into buffer", specialfile);
+	//display_status("buffer contains now: \n%s", beaconbuffer);
 	display_status("Will start beacon tx from file %s ...\n"
 		"You can stop the beacon with <Alt>b .", specialfile);
-//	autorx_on = 1;
-//	beacon_send();
+	return 1;
 }			
 
 /* --------------------------------------------------------------- */
@@ -419,16 +453,17 @@ void beacon_send() {
 	char v = 0;
 
 	if (fixbeacon) {
-	// a fixtext with the [B] magic key is the beacon text
+	// a fixtext with the [B] magic key is already chosen as beacon text
 	    autorx_on = 1;
 	    autotx();
 	    fixtext_send(fixbeacon);
 	}
 	else if (beaconbuffer[0]) {
-	    // else: the before selected file has been read into beaconbuffer
+	    // a file selected before has been read into beaconbuffer
 	    txt = GTK_TEXT(gtk_object_get_data(GTK_OBJECT(wmain), "textedit"));
 	    gtk_text_insert 
-		(txt, NULL, NULL, NULL, beaconbuffer, strlen(beaconbuffer));
+		(txt, radiofont, NULL, NULL, beaconbuffer, strlen(beaconbuffer));
+	    autorx_on = 1;
 	    autotx();
 	    for(l = 0; l < strlen(beaconbuffer); l++) {
 		v = beaconbuffer[l];
@@ -437,18 +472,16 @@ void beacon_send() {
 	}
 	else {
 	    display_status("no beacon text prepared!\n"
-			   "You can select a fixtext with the [B] magic key as beacon text,\n"
-			   "or you can select a file with <Alt>B.");
+		"You can just select a fixtext containing the [B] key as beacon text,\n"
+		"or you can select a file with <Alt>B.");
 	    return;
 	}	
 	autorx_on = 1;
 	beaconcount++;
 	display_status("Beacon count: %d ...", beaconcount);
 	if (beaconcount % 10 == 0) {
-	    display_status("Beacon tx is active !"
-			"Please do not disturb your ham friends and "
-			"do not let your rig unattended !\n"
-			"You can stop the beacon with <Alt>b !");
+	    display_status("HF is running as beacon.\n"
+		"You can stop the beacon with <Alt>b !");
 	}
 }
 
@@ -456,11 +489,12 @@ void beacon_send() {
 
 void beacon_stop() {
 	autorx();
-	display_status("Beacon transmission stopped.");
-	display_status("after %d transmissions", beaconcount);
+	display_status("Beacon transmission stopped");
+	display_status("after %d transmissions.", beaconcount);
 	beaconcount = 0;
-	fixbeacon = 0; // resets nr. of fixtext last sent as beacon
-		       // so next time beacon is again the first selected file
+	fixbeacon = 0; 
+	// would resets nr. of fixtext last sent as beacon
+	// so next time beacon is again the first selected file
 	return;				
 }
 
@@ -730,106 +764,143 @@ void rx_demand_store()
 
 /* --------------------------------------------------------------- */
 
-void userrx() 
-{
-    // user rx / tx beats autorx/tx, so reset the auto functions
-    //display_status("rx on demand -> resetting auto rx and tx");
-    //errprintf((SEV_INFO, "rx on demand -> resetting auto rx and tx");
-	way = RX;
-	autorx_on = 0;
-	autotx_on = 0;
-}
-
-/* --------------------------------------------------------------- */
-
 void usertx() 
 {
-// user rx / tx beats autorx/tx, so reset the auto functions
-//display_status("tx on demand -> resetting auto rx and tx");
-//errprintf((SEV_INFO, "tx on demand -> resetting auto rx and tx");
+	// user-tx beats (switches off) the autorx() function.
+	display_status("tx on demand -> no auto rx.");
+	// errprintf((SEV_INFO, "tx on demand -> resetting auto rx and tx");
 	way = TX;
+	beacon_suspend();
 	autorx_on = 0;
-	autotx_on = 0;
 }
 
 /* --------------------------------------------------------------- */
 
 void autotx()
 {
-/* automatic transmit function;
- * used from callbacks.c: on_text_keypres_event
- * and by the mailbox functions
+/*
+ * automatic transmit function;
+ * used from callbacks.c: on_tx_keypres_event
+ * and by the fixtext & mailbox functions
  */
 	struct hfapp_msg msg;
-	int fittingtx = 0;
+	int fittingtxcmd = 0;
+	if (way == TX) {
+	    //display_status ("autotx: way is tx already."); 
+	    return;
+	}
 
-	if (autotx_on == 1) return;
-	if (way == TX) return;
+	switch (lastrxmsg) {
 
-	autorx_on = 1;
-	autotx_on = 1;	
-	
-	switch (lastrx) {
+    	    case HFAPP_MSG_STATE_PACTOR_STANDBY:
+		fittingtxcmd = HFAPP_MSG_START_PACTOR_FEQ;
+		display_status ("autotx: Pactor Standby -> Pactor FEC"); 
+		break;
 
-	    case HFAPP_MSG_MODE_IRS:
 	    case HFAPP_MSG_STATE_PACTOR_IRS:
+		fittingtxcmd = HFAPP_MSG_MODE_ISS;
+		display_status ("autotx: Pactor IRS -> ISS"); 
+		break;
+
 	    case HFAPP_MSG_STATE_AMTOR_IRS:
+		fittingtxcmd = HFAPP_MSG_MODE_ISS;
+		display_status ("autotx: Amtor IRS -> ISS"); 
+		break;
+
 	    case HFAPP_MSG_STATE_GTOR_IRS:
+		fittingtxcmd = HFAPP_MSG_MODE_ISS;
+		display_status ("autotx: Gtor IRS -> ISS"); 
+		break;
+
 	    case HFAPP_MSG_STATE_PACTOR_ARQ_SLAVECONNECT:
+		fittingtxcmd = HFAPP_MSG_MODE_ISS;
+		display_status ("autotx: Pactor Slaveconnect -> ISS"); 
+		break;
+
 	    case HFAPP_MSG_STATE_AMTOR_ARQ_SLAVECONNECT:
+		fittingtxcmd = HFAPP_MSG_MODE_ISS;
+		display_status ("autotx: Amtor Slaveconnect -> ISS"); 
+		break;
+
 	    case HFAPP_MSG_STATE_GTOR_ARQ_SLAVECONNECT:
-		fittingtx = HFAPP_MSG_MODE_ISS;
-		display_status ("autotx: switch slaveconnect or IRS -> ISS"); 
+		fittingtxcmd = HFAPP_MSG_MODE_ISS;
+		display_status ("autotx: Gtor Slaveconnect -> ISS"); 
 		break;
 
-	    case HFAPP_MSG_START_PACTOR_STANDBY: 
-		fittingtx = HFAPP_MSG_START_PACTOR_FEQ;
-		display_status ("autotx: switch to Pactor FEC"); 
+	    case HFAPP_MSG_STATE_AMTOR_SELFEC_RX:	
+		fittingtxcmd = HFAPP_MSG_MODE_ISS; 
+		display_status ("autotx: Amtor Selfec RX -> ISS"); 
 		break;
 
-	//    case HFAPP_MSG_MODE_QRT: 
-	//	fittingtx = 0;  
-	//	display_status("last command was QRT. No autotx possible.");
-	//	return;
-	//	break;
-
-
 	    case HFAPP_MSG_STATE_AMTOR_COLFEC_RX:
-		fittingtx = HFAPP_MSG_START_AMTOR_COLFEQ;
-		display_status ("autotx: switch to Amtor COLFEC"); 
+		fittingtxcmd = HFAPP_MSG_START_AMTOR_COLFEQ;
+		display_status ("autotx: Amtor Colfec RX -> Amtor colfec TX"); 
 		break;
-		
-	    case HFAPP_MSG_STATE_AMTOR_FEC_CONNECT:
-	    case HFAPP_MSG_STATE_AMTOR_SELFEC_RX:	
-		//fitttingtx = HFAPP_MSG_START_AMTOR_SELFEC; gibts nicht
-		fittingtx = HFAPP_MSG_MODE_ISS; 
-		display_status ("autotx: switch to ISS"); 
-		break;
-		
 
-	    case HFAPP_MSG_START_RTTY_RX:
 	    case HFAPP_MSG_STATE_RTTY_RX:
-		fittingtx = HFAPP_MSG_START_RTTY_TX;
-		display_status ("autotx: switch to RTTY TX"); 
+		fittingtxcmd = HFAPP_MSG_START_RTTY_TX;
+		display_status ("autotx: RTTY RX -> TX"); 
+		break;
+
+	    case HFAPP_MSG_STATE_MT63_RX:
+		fittingtxcmd = HFAPP_MSG_START_MT63_TX;
+		display_status ("autotx: MT63 RX -> TX"); 
 		break;
 
 	    default:
-		fittingtx = lasttx;
-		if ( fittingtx == 0 ) {   
-		    display_status("error finding auto rx mode: %d", fittingtx);
-		    return;
+		//not every command results in a message from hfkernel.
+		//display_status 
+		//    ("autotx: last RX msg not clear. Checking last TX cmd."); 
+
+		switch (lasttxcmd) {
+
+		    case HFAPP_MSG_START_PACTOR_ARQ:
+			fittingtxcmd = HFAPP_MSG_START_PACTOR_FEQ;
+			display_status ("autotx: Standby -> Pactor FEC"); 
+			break;
+
+		    case HFAPP_MSG_START_PACTOR_FEQ:
+			fittingtxcmd = HFAPP_MSG_START_PACTOR_FEQ;
+			display_status ("autotx: Standby -> Pactor FEC"); 
+			break;
+
+		    case HFAPP_MSG_START_GTOR_ARQ:
+			fittingtxcmd = HFAPP_MSG_START_PACTOR_FEQ;
+			display_status ("autotx: Standby -> Pactor FEC"); 
+			break;
+
+		    case HFAPP_MSG_START_AMTOR_ARQ:  
+			fittingtxcmd = HFAPP_MSG_START_AMTOR_SELFEQ;
+			display_status ("autotx: Standby -> Amtor Selfec"); 
+			break;
+	    		
+		    case HFAPP_MSG_START_AMTOR_COLFEQ:  
+			fittingtxcmd = HFAPP_MSG_START_AMTOR_COLFEQ;
+			display_status ("autotx: Standby -> Amtor Colfec"); 
+			break;
+	    		
+		    case HFAPP_MSG_START_AMTOR_SELFEQ: 
+			fittingtxcmd = HFAPP_MSG_START_AMTOR_SELFEQ;
+			display_status ("autotx: Standby -> Amtor Selfec"); 
+			break;
+	    
+		    default:
+		    // here unclear what to do -> do what user did last 	
+			display_status("autotx: did not find last tx mode.");
+			fittingtxcmd = HFAPP_MSG_START_PACTOR_FEQ;
+			display_status ("-> guess and switch to Pactor FEC..."); 
+			break;
 		}
 		break;
 	}
 	
 	msg.hdr.err = htonl(ERR_NOERR);
 	msg.hdr.len = htonl(0);
-	msg.hdr.type = htonl(fittingtx);
+	msg.hdr.type = htonl(fittingtxcmd);
 	msg_send(&msg);
- 	//display_status("AUTO TRANSMIT LAST TX MODE: %d", fittingtx);
-	lasttx = fittingtx;
+// 	display_status("autotx(): sending msg for mode %d", fittingtxcmd);
+	lasttxcmd = fittingtxcmd;
 	autorx_on = 1;
-	autotx_on = 1;	
 	way = TX;
 	return;
 }
@@ -839,89 +910,199 @@ void autotx()
 void autorx()
 {
 	struct hfapp_msg msg;
-	int fittingrx;
+	int fittingrxcmd;
 
-	if (way	== RX) return;
+	if (way	== RX) {
+	    //display_status("autorx(): way is rx already.");
+	    return;
+	}
 	if (autorx_on == 0) {
-	    display_status ("autorx_on = 0. No autorx."); 
+	    //display_status ("autorx_on = 0. No autorx."); 
+	    return;
+	} 
+	if (arq) {
+	    //display_status 
+		//("ARQ mode running. It will handle tx->rx better. No autorx."); 
 	    return;
 	} 
 	//display_status ("autorx_on = 1. Preparing autorx function."); 
 	//errprintf(SEV_INFO, "autorx_on = 1. Preparing autorx function."); 
+//	display_status 
+//	    ("autorx: Checking last tx msg..."); 
 	
-        switch (lasttx) {
-	    case HFAPP_MSG_MODE_ISS:
-	    case HFAPP_MSG_STATE_PACTOR_ISS:
-	    case HFAPP_MSG_STATE_AMTOR_ISS:
-	    case HFAPP_MSG_STATE_GTOR_ISS:
-	    case HFAPP_MSG_STATE_AMTOR_ARQ_MASTERCONNECT:
-	    case HFAPP_MSG_STATE_GTOR_ARQ_MASTERCONNECT:
-		fittingrx = HFAPP_MSG_MODE_IRS;
-		display_status ("autorx: switch to IRS"); 
-		break;
+        switch (lasttxmsg) {
 
-	    case HFAPP_MSG_START_PACTOR_FEQ: 
 	    case HFAPP_MSG_STATE_PACTOR_ARQ_DISCONNECT:
-		fittingrx = HFAPP_MSG_START_PACTOR_STANDBY;
-		display_status ("autorx: switch to Pactor Standby"); 
+		// Disconnect msgs are treated as tx msgs
+		// so that autorx works and switches to standby !
+		fittingrxcmd = HFAPP_MSG_START_STANDBY;
+		qrt_pending = 0;
+		display_status 
+		    ("autorx: Pactor ARQ Disconnect -> Standby"); 
 		break;
 
-	    case HFAPP_MSG_MODE_QRT:
-	    case HFAPP_MSG_START_AMTOR_COLFEQ:
-	    case HFAPP_MSG_START_AMTOR_SELFEQ:
-	    case HFAPP_MSG_STATE_AMTOR_FEC_CONNECT:
-	    case HFAPP_MSG_STATE_AMTOR_FEC_DISCONNECT:
 	    case HFAPP_MSG_STATE_AMTOR_ARQ_DISCONNECT:
-	    case HFAPP_MSG_STATE_GTOR_ARQ_DISCONNECT:
-		fittingrx =  HFAPP_MSG_START_STANDBY;
-		display_status ("autorx: switch to Standby"); 
+		// Disconnect msgs are treated as tx msgs
+		// so that autorx works and switches to standby !
+		fittingrxcmd = HFAPP_MSG_START_STANDBY;
+		qrt_pending = 0;
+		display_status 
+		    ("autorx: Amtor ARQ Disconnect -> Standby"); 
 		break;
 
-	    case HFAPP_MSG_START_RTTY_TX:
-	    case HFAPP_MSG_STATE_RTTY_TX:
-		fittingrx = HFAPP_MSG_START_RTTY_RX;
-		display_status ("autorx: switch to RTTX RX"); 
-//		errprintf(SEV_INFO, "autorx: switch to RTTX RX\n"); 
+	    case HFAPP_MSG_STATE_AMTOR_FEC_DISCONNECT:
+		// Disconnect msgs are treated as tx msgs
+		// so that autorx works and switches to standby !
+		fittingrxcmd = HFAPP_MSG_START_STANDBY;
+		qrt_pending = 0;
+		display_status 
+		    ("autorx: Amtor FEC Disconnect -> Standby"); 
 		break;
-		
+
+	    case HFAPP_MSG_STATE_GTOR_ARQ_DISCONNECT:
+		// Disconnect msgs are treated as tx msgs
+		// so that autorx works and switches to standby !
+		fittingrxcmd = HFAPP_MSG_START_STANDBY;
+		qrt_pending = 0;
+		display_status 
+		    ("autorx: Gtor ARQ Disconnect -> Standby"); 
+		break;
+
+	    case HFAPP_MSG_STATE_PACTOR_FEC_CONNECT:
+		// bad name, just means fec tx
+		fittingrxcmd = HFAPP_MSG_START_STANDBY;
+		// was before: Pactor only.
+		// But: if mailbox-beacon in p-fec running,
+		// still Amtor Connect for mailbox shall be possible.
+		display_status 
+		    ("autorx: Pactor FEC -> Standby"); 
+		break;
+
+	    case HFAPP_MSG_STATE_PACTOR_ISS:
+		fittingrxcmd = HFAPP_MSG_MODE_IRS;
+		display_status ("autorx: Pactor ISS -> IRS"); 
+		break;
+
+	    case HFAPP_MSG_STATE_AMTOR_ISS:
+		fittingrxcmd = HFAPP_MSG_MODE_IRS;
+		display_status ("autorx: Amtor ISS -> IRS"); 
+		break;
+
+	    case HFAPP_MSG_STATE_GTOR_ISS:
+		fittingrxcmd = HFAPP_MSG_MODE_IRS;
+		display_status ("autorx: Gtor ISS -> IRS"); 
+		break;
+
+	    case HFAPP_MSG_STATE_PACTOR_ARQ_MASTERCONNECT:
+		fittingrxcmd = HFAPP_MSG_MODE_IRS;
+		lastrxmsg = HFAPP_MSG_STATE_PACTOR_IRS; 
+		/* it should come, but after fresh master connect it 
+		  lasts too long -> erroneous switch from 
+		  (wrong guessed) standby to e.g. Pactor FEC by 
+		  next autotx !! So i insert it artificially... */
+		display_status ("autorx: Pactor Master Connect -> IRS"); 
+		break;
+
+	    case HFAPP_MSG_STATE_AMTOR_ARQ_MASTERCONNECT:
+		fittingrxcmd = HFAPP_MSG_MODE_IRS;
+		lastrxmsg = HFAPP_MSG_STATE_AMTOR_IRS; 
+		/* it should come, but after fresh master connect it 
+		  lasts too long -> erroneous switch from 
+		  (wrong guessed) standby to e.g. Amtor Col-FEC by 
+		  next autotx !! So i insert it artificially... */
+		display_status ("autorx: Amtor Master Connect -> IRS"); 
+		break;
+
+	    case HFAPP_MSG_STATE_GTOR_ARQ_MASTERCONNECT:
+		fittingrxcmd = HFAPP_MSG_MODE_IRS;
+		lastrxmsg = HFAPP_MSG_STATE_GTOR_IRS; 
+		/* it should come, but after fresh master connect it 
+		  lasts too long -> erroneous switch from 
+		  (wrong guessed) standby to e.g. Pactor FEC by 
+		  next autotx !! So i insert it artificially... */
+		display_status ("autorx: Gtor Master Connect -> IRS"); 
+		break;
+
+	    case HFAPP_MSG_STATE_RTTY_TX:
+		fittingrxcmd = HFAPP_MSG_START_RTTY_RX;
+		display_status ("autorx: RTTX TX -> RX"); 
+		break;
+
+	    case HFAPP_MSG_STATE_MT63_TX:
+		fittingrxcmd = HFAPP_MSG_START_MT63_RX;
+		display_status ("autorx: MT63 TX -> RX"); 
+		break;
+
 	    default:
-	    	fittingrx = lastrx;
-//		display_status ("autorx: switch back to last used RX mode"); 		
-		if ( fittingrx == 0 ) {   
-		    display_status("error in finding last rx mode: %d", 
-			fittingrx);
-		    errprintf(SEV_WARNING, 
-			"autorx: error finding last rx mode: %d", fittingrx); 
-    		    fittingrx =  HFAPP_MSG_START_STANDBY;
-		    display_status 
-			("but because autorx should always work "
-			"we switch to Pactor/Amtor/Gtor Standby"); 
+		/*not every command results in a message from hfkernel.*/
+		//display_status 
+		//    ("autorx: last TX msg not clear. Checking last TX cmd."); 
+		switch (lasttxcmd) {
+
+		    case HFAPP_MSG_MODE_ISS:
+			fittingrxcmd = HFAPP_MSG_MODE_IRS;
+			//display_status ("autorx: ISS -> IRS"); 
+			break;
+
+		    case HFAPP_MSG_START_PACTOR_FEQ: 
+			// was before: Pactor only.
+			// But: if mailbox-beacon in p-fec running,
+			// still Amtor Connect for mailbox shall be possible.
+			fittingrxcmd = HFAPP_MSG_START_STANDBY;
+			display_status 
+			    ("autorx: Pactor FEC -> Standby"); 
+			break;
+
+		    case HFAPP_MSG_START_AMTOR_COLFEQ:
+			fittingrxcmd = HFAPP_MSG_START_STANDBY;
+			display_status 
+			    ("autorx: Amtor Colfec -> Standby"); 
+			break;
+
+		    case HFAPP_MSG_START_AMTOR_SELFEQ:
+			fittingrxcmd = HFAPP_MSG_START_STANDBY;
+			display_status 
+			    ("autorx: Amtor Selfec -> Standby"); 
+			break;
+
+		    case HFAPP_MSG_START_RTTY_TX:
+			fittingrxcmd = HFAPP_MSG_START_RTTY_RX;
+			display_status ("autorx: RTTX TX -> RX"); 
+			break;
+		
+		    case HFAPP_MSG_MODE_QRT:
+			fittingrxcmd = HFAPP_MSG_START_STANDBY;
+			qrt_pending = 0;
+			display_status 
+			    ("autorx: QRT -> Standby"); 
+			break;
+		    
+		    default:
+	    		fittingrxcmd = lastrxcmd;
+			if ( ! fittingrxcmd ) {   
+			    display_status("autorx: did not find last rx mode.");
+			    fittingrxcmd = HFAPP_MSG_START_STANDBY;
+			    display_status 
+			    ("autorx: -> I guess and switch to Pactor Amtor Gtor Standby"); 
+			} else {
+			    display_status
+				("autorx: switching to last rx mode: %d", fittingrxcmd);
+			}
+			break;
 		}
 		break;
 	}
-
 /* 
- * trial: send QRT msg
- 
-	msg.hdr.err = htonl(ERR_NOERR);
-	msg.hdr.len = htonl(0);
-	msg.hdr.type = htonl(HFAPP_MSG_MODE_QRT);
-	msg_send(&msg);
-	display_status("QRT");
-*/
-
-/* 
- *  switch to the fittingrx mode by sending a msg
+ *  switch to the fittingrxcmd mode by sending a msg
  */
-
 	msg.hdr.err = htonl(ERR_NOERR);
 	msg.hdr.len = htonl(0);
-	msg.hdr.type = htonl(fittingrx);
+	msg.hdr.type = htonl(fittingrxcmd);
 	msg_send(&msg);
-	//display_status("AUTO RECEIVE MODE: %d", fittingrx);
-	//errprintf(SEV_INFO, "autorx: auto rx mode %d", fittingrx); 
-	lastrx = fittingrx;
-	userrx();
+	//display_status("AUTO RECEIVE MODE: %d", fittingrxcmd);
+	//errprintf(SEV_INFO, "autorx: auto rx mode %d", fittingrxcmd); 
+	lastrxcmd = fittingrxcmd;
+	way = RX;
 	return;
 }
 
@@ -930,13 +1111,16 @@ void autorx()
 void qrt() {
 	struct hfapp_msg msg;
 
+	if (!arq) return;
 	msg.hdr.err = htonl(ERR_NOERR);
 	msg.hdr.len = htonl(0);
 	msg.hdr.type = htonl(HFAPP_MSG_MODE_QRT);
 	msg_send(&msg);
 	display_status("automatic QRT.");
-	lasttx = HFAPP_MSG_MODE_QRT;
-	qrt_pending = 0;
+	lasttxcmd = HFAPP_MSG_MODE_QRT; /* qrt is a tx !!! */
+	way = TX; /* if this is not so, autorx will not work*/
+	autorx_on = 1;
+	qrt_pending = 1;  // means we are waiting for qrt machine to finish
 }
 
 /* --------------------------------------------------------------------- */
