@@ -1,5 +1,5 @@
 /* 
- * Sooundmodem Spectrum Widget
+ * Soundmodem Spectrum Widget
  * Copyright (C) 1999 Thomas Sailer <sailer@ife.ee.ethz.ch>
  *
  * This library is free software; you can redistribute it and/or
@@ -32,6 +32,18 @@
 
 /* --------------------------------------------------------------------- */
 
+#define SQUELCHPOINTS 9
+guint squelch = 0;
+int squelchpercent = 10;
+int squelch_passed_fsk;
+int squelch_passed_cw;
+int squelch_passed_mt36_500_1000;
+int squelch_passed_mt36_1000_1500;
+int squelch_passed_mt36_1500_2500;
+/* last 2 prepared for mt63_bandwidth_auto_detect() to come in sha allah ! */
+
+/* --------------------------------------------------------------------- */
+
 static inline float hamming(float x)
 {
         return 0.54-0.46*cos(2*M_PI*x);
@@ -186,6 +198,9 @@ static void spectrum_init(Spectrum *spec)
 	spec->gridcol.red = 52429;
 	spec->gridcol.green = 52429;
 	spec->gridcol.blue = 52429;
+	spec->squelchcol.red = 10000; // 0
+	spec->squelchcol.green = 45000; // 52429;
+	spec->squelchcol.blue = 0;
 	spec->spacecol.red = 65535;
 	spec->spacecol.green = 0;
 	spec->spacecol.blue = 24903;
@@ -195,7 +210,8 @@ static void spectrum_init(Spectrum *spec)
 	spec->pointercol.red = 65535;
 	spec->pointercol.green = 0;
 	spec->pointercol.blue = 65535;
-	spec->trace_gc = spec->grid_gc = spec->space_gc = spec->mark_gc = spec->pointer_gc = NULL;
+	spec->trace_gc = spec->squelch_gc = spec->grid_gc = spec->space_gc = 
+            spec->mark_gc = spec->pointer_gc = NULL;
 	spec->pixmap = NULL;
 	/* initialize the data */
 	memset(&spec->y, 0, sizeof(spec->y));
@@ -248,6 +264,13 @@ static void spectrum_realize(GtkWidget *widget)
 	spec->grid_gc = gtk_gc_get(widget->style->depth,
 				   widget->style->colormap,
 				   &gc_values, GDK_GC_FOREGROUND);
+	if (!gdk_color_alloc(widget->style->colormap, &spec->squelchcol))
+		g_warning("unable to allocate color: ( %d %d %d )",
+			  spec->squelchcol.red, spec->squelchcol.green, spec->squelchcol.blue);
+	gc_values.foreground = spec->squelchcol;
+	spec->squelch_gc = gtk_gc_get(widget->style->depth,
+				    widget->style->colormap,
+				    &gc_values, GDK_GC_FOREGROUND);
 	if (!gdk_color_alloc(widget->style->colormap, &spec->spacecol))
 		g_warning("unable to allocate color: ( %d %d %d )",
 			  spec->spacecol.red, spec->spacecol.green, spec->spacecol.blue);
@@ -287,6 +310,8 @@ static void spectrum_unrealize(GtkWidget *widget)
 		gtk_idle_remove(spec->idlefunc);
 	if (spec->trace_gc)
 		gtk_gc_release(spec->trace_gc);
+	if (spec->squelch_gc)
+		gtk_gc_release(spec->squelch_gc);
 	if (spec->grid_gc)
 		gtk_gc_release(spec->grid_gc);
 	if (spec->space_gc)
@@ -295,7 +320,8 @@ static void spectrum_unrealize(GtkWidget *widget)
 		gtk_gc_release(spec->mark_gc);
 	if (spec->pointer_gc)
 		gtk_gc_release(spec->pointer_gc);
-	spec->trace_gc = spec->grid_gc = spec->space_gc = spec->mark_gc = spec->pointer_gc = NULL;
+	spec->trace_gc = spec->grid_gc = spec->space_gc = 
+            spec->squelch_gc = spec->mark_gc = spec->pointer_gc = NULL;
 	if (spec->pixmap)
 			gdk_pixmap_unref(spec->pixmap);
 	spec->pixmap = NULL;
@@ -348,7 +374,8 @@ GtkWidget* spectrum_new(const char *name, void *dummy0, void *dummy1, unsigned i
 	spec = gtk_type_new(spectrum_get_type());
 	memset(&spec->y, 0, sizeof(spec->y));
 	for (i = 0; i < SPECTRUM_NUMSAMPLES; i++)
-		spec->window[i] = (1.0 / 32767.0 / SPECTRUM_NUMSAMPLES) * hamming(i * (1.0 / (SPECTRUM_NUMSAMPLES-1)));
+		spec->window[i] = (1.0 / 32767.0 / SPECTRUM_NUMSAMPLES) * 
+                    hamming(i * (1.0 / (SPECTRUM_NUMSAMPLES-1)));
 	return GTK_WIDGET(spec);
 }
 
@@ -380,38 +407,62 @@ static void draw(Spectrum *spec)
 	GdkPoint pt[SPECTRUM_WIDTH+1];
 	GdkSegment seg[100], *segp;
 	GtkWidget *widget;
-
+        GdkSegment squelchline[1];
+        
+// 
 	widget = GTK_WIDGET(spec);
 	g_return_if_fail(GTK_WIDGET_DRAWABLE(widget));
 	g_return_if_fail(spec->pixmap);
 	/* calculate grid segments */
-	for (segp = seg, segcnt = i = 0; i < SPECTRUM_WIDTH; i += (SPECTRUM_WIDTH * 500 + SRATE/4) / (SRATE/2)) {
+        /* vertical: */
+	for ( segp = seg, segcnt = i = 0; 
+                i < SPECTRUM_WIDTH; 
+                i += (SPECTRUM_WIDTH * 500 + SRATE/4) / (SRATE/2)) {
 		segp->x1 = segp->x2 = i;
 		segp->y1 = 0;
 		segp->y2 = SPECTRUM_HEIGHT-1;
 		segp++;
 		segcnt++;
 	}
-	for (i = 0; i < SPECTRUM_HEIGHT; i += (SPECTRUM_HEIGHT * 10 + DBSPAN/2) / DBSPAN) {
+	/* horizontal: */
+        for ( i = 0; 
+                    i < SPECTRUM_HEIGHT; 
+                    i += (SPECTRUM_HEIGHT * 10 + DBSPAN/2) / DBSPAN) {
 		segp->y1 = segp->y2 = i;
 		segp->x1 = 0;
 		segp->x2 = SPECTRUM_WIDTH-1;
 		segp++;
 		segcnt++;
 	}
+        /* squelch line: */
+        {
+        // i make the squelch 20 % for first draw
+	// later squelch is set by click on vruler right side
+                if (! squelch) 
+		    squelch = SPECTRUM_HEIGHT * (100 - squelchpercent) / 100; 
+                i = squelch;
+                //display_status("squelchpercent = %d", squelchpercent);
+                //display_status("squelch = %d", i);
+                segp = squelchline;
+                segp->y1 = segp->y2 = i;
+                segp->x1 = 0;
+                segp->x2 = SPECTRUM_WIDTH-1;
+	}
 	/* copy data points */
 	for (i = 0; i < SPECTRUM_WIDTH; i++) {
 		pt[i].x = i;
 		pt[i].y = spec->y[i];
 	}
-	/* clear window */
+        /* clear window */
 	gdk_draw_rectangle(spec->pixmap, widget->style->base_gc[widget->state],
 			   TRUE, 0, 0, 
 			   widget->allocation.width, 
 			   widget->allocation.height);
 	/* draw grid */
 	gdk_draw_segments(spec->pixmap, spec->grid_gc, seg, segcnt);
-	/* draw markers */
+        /* draw squelch */
+        gdk_draw_segments(spec->pixmap, spec->squelch_gc, squelchline, 1);
+        /* draw markers */
 	gdk_draw_line(spec->pixmap, spec->space_gc, 
 		      spec->space,
 		      0, 
@@ -451,9 +502,46 @@ void spectrum_setdata(Spectrum *spec, short *samples)
 	float fdata[2*SPECTRUM_NUMSAMPLES];
 	float f;
 	unsigned int i;
+	static unsigned int squelch_checkpoints[SQUELCHPOINTS];
+	unsigned short squelch_y[SQUELCHPOINTS];
+	
+	/*
+	 * 0 cw
+	 * 1 fsk space
+	 * 2 fsk mark
+	 * 3 mt36_500_1000_a;		 600 Hz
+	 * 4 mt36_500_1000_b;		 900 Hz
+	 * 5 mt36_1000_1500_a;		1100 Hz
+	 * 6 mt36_1000_1500_b;		1400 Hz
+	 * 7 mt36_1500_2500_a;		1700 Hz
+	 * 8 mt36_1500_2500_b;		2300 Hz
+	 *
+    	 * 5 - 8 prepared for mt63_bandwidth_auto_detect() 
+	 * to come inshallah ! 
+	 */
+	if (! squelch_checkpoints[0])
+	squelch_checkpoints[0] = (SPECTRUM_WIDTH * 440 + SRATE/4) / (SRATE/2); 
+	// cw mode planned with 440 Hz default, to be parametrized later
+	if (! squelch_checkpoints[1])	
+	squelch_checkpoints[1] = spec->space;
+	if (! squelch_checkpoints[2])
+	squelch_checkpoints[2] = spec->mark;
+	if (! squelch_checkpoints[3])
+	squelch_checkpoints[3] = (SPECTRUM_WIDTH * 600 + SRATE/4) / (SRATE/2);
+	if (! squelch_checkpoints[4])	
+	squelch_checkpoints[4] = (SPECTRUM_WIDTH * 900 + SRATE/4) / (SRATE/2);	
+	if (! squelch_checkpoints[5])	
+	squelch_checkpoints[5] = (SPECTRUM_WIDTH * 1100 + SRATE/4) / (SRATE/2);
+	if (! squelch_checkpoints[6])	
+	squelch_checkpoints[6] = (SPECTRUM_WIDTH * 1400 + SRATE/4) / (SRATE/2);
+	if (! squelch_checkpoints[7])	
+	squelch_checkpoints[7] = (SPECTRUM_WIDTH * 1700 + SRATE/4) / (SRATE/2);
+	if (! squelch_checkpoints[8])	
+	squelch_checkpoints[8] = (SPECTRUM_WIDTH * 2300 + SRATE/4) / (SRATE/2);	
 
 	g_return_if_fail(spec != NULL);
 	g_return_if_fail(IS_SPECTRUM(spec));
+	
 	for (i = 0; i < SPECTRUM_NUMSAMPLES; i++) {
 		fdata[2*i] = samples[i] * spec->window[i];
 		fdata[2*i+1] = 0;
@@ -467,10 +555,35 @@ void spectrum_setdata(Spectrum *spec, short *samples)
 		if (f > SPECTRUM_HEIGHT-1)
 			f = SPECTRUM_HEIGHT-1;
 		spec->y[i] = f;
+        }
+	/* routines for squelch */
+	/* big y means weak signal */
+	for (i = 0; i < SQUELCHPOINTS; i++) {
+            squelch_y[i] = spec->y[squelch_checkpoints[i]];
+	    /*
+	    display_status("signal at squelch-checkpoint %d: %d", 
+		i, squelch_y[i]);
+	    */
 	}
+	if (squelch_y[0] < squelch) squelch_passed_cw = 1;
+	else squelch_passed_cw = 0;
+	if ((squelch_y[1] < squelch) || (squelch_y[2] < squelch))
+	    squelch_passed_fsk = 1; 
+	else  squelch_passed_fsk = 0;
+	if ((squelch_y[3] < squelch) || (squelch_y[4] < squelch))
+	    squelch_passed_mt36_500_1000 = 1; 
+	else squelch_passed_mt36_500_1000 = 0;
+	if ((squelch_y[5] < squelch) || (squelch_y[6] < squelch))
+	    squelch_passed_mt36_1000_1500 = 1; 
+	else squelch_passed_mt36_1000_1500 = 0;
+	if ((squelch_y[7] < squelch) || (squelch_y[8] < squelch))
+	    squelch_passed_mt36_1500_2500 = 1; 
+	else squelch_passed_mt36_1500_2500 = 0;
+        /* end of routines for squelch */
 	if (GTK_WIDGET_DRAWABLE(GTK_WIDGET(spec))) {
-		if (!spec->idlefunc)
-			spec->idlefunc = gtk_idle_add_priority(PRIO, idle_callback, spec);
+	    if (!spec->idlefunc)
+		spec->idlefunc = 
+		    gtk_idle_add_priority(PRIO, idle_callback, spec);
 	}
 }
 
@@ -490,8 +603,6 @@ void spectrum_setmarker(Spectrum *spec, int space, int mark, int pointer)
 	}
 }
 
-// I moved the following from main to here. Gnther
-
 //static 
 void set_fsk_freq(unsigned int mark, unsigned int space)
 {
@@ -690,7 +801,6 @@ void scope_draw(float *data)
 #endif
 }
 
-
 void spec_samples(short *data, unsigned int len)
 {
 	struct hfapp_msg msg;
@@ -764,7 +874,7 @@ void set_freq_shift(int shift)
             default:
         	tog = GTK_TOGGLE_BUTTON(gtk_object_get_data
 			(GTK_OBJECT(wspec), "shiftother"));
-        	display_status("user-defined shift %d", shift);
+        	//display_status("user-defined shift %d", shift);
 	        break;
             }
 	if(tog) gtk_toggle_button_set_active(tog, TRUE);
