@@ -107,7 +107,7 @@ void output()
  */
 	printf(	"Corrections: \n" 
 	    "\t***  soundcorr:   (hfkernel option -s):\t%10.8f  ***\n"
-	    "\t***  mhzcorr:     (hfkernel option -m):\t%10.0f  ***\n"
+	    "\t***  mhzcorr:     (hfkernel option -m):\t%10.6f  ***\n"
 	    "\t***  timecorr:    (hfkernel option -t):\t%10.8f  ***\n",
 	    soundcorr, mhzcorr, timecorr);
 
@@ -152,7 +152,7 @@ void output()
  */
 	sprintf(factors, "## reffreq calibration:\n" 
 	    "soundcorr=%10.8f\n"
-	    "mhzcorr=%.0f\n"
+	    "mhzcorr=%10.6f\n"
 	    "timecorr=%10.8f\n",
 	    soundcorr, mhzcorr, timecorr);
 //	    printf( "factors string prepared\n"); 
@@ -410,7 +410,7 @@ static int process_input(short *s, unsigned int samples,
 		    printf("peak index: %d\n", idx);
 		    f = (float)idx / inp_freq;
 		    tvcorr = (float)idx / inp_freq / (tm2 - tm2start) * 1000000;
-		    cpu_mhz = (tm3 - tm3start) / (float)idx * inp_freq;
+		    cpu_mhz = (float)(tm3 - tm3start) / (float)idx * inp_freq / 1000000;
 		    /*
 		    this is original by Tom
 		    printf("gettimeofday correction: %10.7f  CPU clock: %10.1f\n"
